#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ApplyCodeRequest(object):

    def __init__(self):
        self._biz_code = None
        self._biz_id = None
        self._context_data = None
        self._logo_url = None

    @property
    def biz_code(self):
        return self._biz_code

    @biz_code.setter
    def biz_code(self, value):
        self._biz_code = value
    @property
    def biz_id(self):
        return self._biz_id

    @biz_id.setter
    def biz_id(self, value):
        self._biz_id = value
    @property
    def context_data(self):
        return self._context_data

    @context_data.setter
    def context_data(self, value):
        self._context_data = value
    @property
    def logo_url(self):
        return self._logo_url

    @logo_url.setter
    def logo_url(self, value):
        self._logo_url = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_code:
            if hasattr(self.biz_code, 'to_alipay_dict'):
                params['biz_code'] = self.biz_code.to_alipay_dict()
            else:
                params['biz_code'] = self.biz_code
        if self.biz_id:
            if hasattr(self.biz_id, 'to_alipay_dict'):
                params['biz_id'] = self.biz_id.to_alipay_dict()
            else:
                params['biz_id'] = self.biz_id
        if self.context_data:
            if hasattr(self.context_data, 'to_alipay_dict'):
                params['context_data'] = self.context_data.to_alipay_dict()
            else:
                params['context_data'] = self.context_data
        if self.logo_url:
            if hasattr(self.logo_url, 'to_alipay_dict'):
                params['logo_url'] = self.logo_url.to_alipay_dict()
            else:
                params['logo_url'] = self.logo_url
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ApplyCodeRequest()
        if 'biz_code' in d:
            o.biz_code = d['biz_code']
        if 'biz_id' in d:
            o.biz_id = d['biz_id']
        if 'context_data' in d:
            o.context_data = d['context_data']
        if 'logo_url' in d:
            o.logo_url = d['logo_url']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class KoubeiCateringDishDictionaryQueryModel(object):

    def __init__(self):
        self._biz_type = None
        self._dictionary_id = None
        self._ext_info = None
        self._merchant_id = None
        self._status = None

    @property
    def biz_type(self):
        return self._biz_type

    @biz_type.setter
    def biz_type(self, value):
        self._biz_type = value
    @property
    def dictionary_id(self):
        return self._dictionary_id

    @dictionary_id.setter
    def dictionary_id(self, value):
        self._dictionary_id = value
    @property
    def ext_info(self):
        return self._ext_info

    @ext_info.setter
    def ext_info(self, value):
        self._ext_info = value
    @property
    def merchant_id(self):
        return self._merchant_id

    @merchant_id.setter
    def merchant_id(self, value):
        self._merchant_id = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_type:
            if hasattr(self.biz_type, 'to_alipay_dict'):
                params['biz_type'] = self.biz_type.to_alipay_dict()
            else:
                params['biz_type'] = self.biz_type
        if self.dictionary_id:
            if hasattr(self.dictionary_id, 'to_alipay_dict'):
                params['dictionary_id'] = self.dictionary_id.to_alipay_dict()
            else:
                params['dictionary_id'] = self.dictionary_id
        if self.ext_info:
            if hasattr(self.ext_info, 'to_alipay_dict'):
                params['ext_info'] = self.ext_info.to_alipay_dict()
            else:
                params['ext_info'] = self.ext_info
        if self.merchant_id:
            if hasattr(self.merchant_id, 'to_alipay_dict'):
                params['merchant_id'] = self.merchant_id.to_alipay_dict()
            else:
                params['merchant_id'] = self.merchant_id
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KoubeiCateringDishDictionaryQueryModel()
        if 'biz_type' in d:
            o.biz_type = d['biz_type']
        if 'dictionary_id' in d:
            o.dictionary_id = d['dictionary_id']
        if 'ext_info' in d:
            o.ext_info = d['ext_info']
        if 'merchant_id' in d:
            o.merchant_id = d['merchant_id']
        if 'status' in d:
            o.status = d['status']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayPcreditHuabeiAuthOrderUnfreezeResponse(AlipayResponse):

    def __init__(self):
        super(AlipayPcreditHuabeiAuthOrderUnfreezeResponse, self).__init__()
        self._agreement_no = None
        self._agreement_status = None
        self._alipay_user_id = None
        self._auth_opt_id = None
        self._gmt_trans = None
        self._out_request_no = None
        self._rest_freeze_amount = None
        self._seller_id = None
        self._trans_status = None
        self._unfreeze_amount = None

    @property
    def agreement_no(self):
        return self._agreement_no

    @agreement_no.setter
    def agreement_no(self, value):
        self._agreement_no = value
    @property
    def agreement_status(self):
        return self._agreement_status

    @agreement_status.setter
    def agreement_status(self, value):
        self._agreement_status = value
    @property
    def alipay_user_id(self):
        return self._alipay_user_id

    @alipay_user_id.setter
    def alipay_user_id(self, value):
        self._alipay_user_id = value
    @property
    def auth_opt_id(self):
        return self._auth_opt_id

    @auth_opt_id.setter
    def auth_opt_id(self, value):
        self._auth_opt_id = value
    @property
    def gmt_trans(self):
        return self._gmt_trans

    @gmt_trans.setter
    def gmt_trans(self, value):
        self._gmt_trans = value
    @property
    def out_request_no(self):
        return self._out_request_no

    @out_request_no.setter
    def out_request_no(self, value):
        self._out_request_no = value
    @property
    def rest_freeze_amount(self):
        return self._rest_freeze_amount

    @rest_freeze_amount.setter
    def rest_freeze_amount(self, value):
        self._rest_freeze_amount = value
    @property
    def seller_id(self):
        return self._seller_id

    @seller_id.setter
    def seller_id(self, value):
        self._seller_id = value
    @property
    def trans_status(self):
        return self._trans_status

    @trans_status.setter
    def trans_status(self, value):
        self._trans_status = value
    @property
    def unfreeze_amount(self):
        return self._unfreeze_amount

    @unfreeze_amount.setter
    def unfreeze_amount(self, value):
        self._unfreeze_amount = value

    def parse_response_content(self, response_content):
        response = super(AlipayPcreditHuabeiAuthOrderUnfreezeResponse, self).parse_response_content(response_content)
        if 'agreement_no' in response:
            self.agreement_no = response['agreement_no']
        if 'agreement_status' in response:
            self.agreement_status = response['agreement_status']
        if 'alipay_user_id' in response:
            self.alipay_user_id = response['alipay_user_id']
        if 'auth_opt_id' in response:
            self.auth_opt_id = response['auth_opt_id']
        if 'gmt_trans' in response:
            self.gmt_trans = response['gmt_trans']
        if 'out_request_no' in response:
            self.out_request_no = response['out_request_no']
        if 'rest_freeze_amount' in response:
            self.rest_freeze_amount = response['rest_freeze_amount']
        if 'seller_id' in response:
            self.seller_id = response['seller_id']
        if 'trans_status' in response:
            self.trans_status = response['trans_status']
        if 'unfreeze_amount' in response:
            self.unfreeze_amount = response['unfreeze_amount']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
'''
Created on 2017-12-20

@author: liuqun
'''


COMMON_PARAM_KEYS = set()

P_APP_ID = "app_id"
COMMON_PARAM_KEYS.add(P_APP_ID)

P_METHOD = "method"
COMMON_PARAM_KEYS.add(P_METHOD)

P_FORMAT = "format"
COMMON_PARAM_KEYS.add(P_FORMAT)

P_CHARSET = "charset"
COMMON_PARAM_KEYS.add(P_CHARSET)

P_SIGN_TYPE = "sign_type"
COMMON_PARAM_KEYS.add(P_SIGN_TYPE)

P_SIGN = "sign"
COMMON_PARAM_KEYS.add(P_SIGN)

P_ENCRYPT_TYPE = "encrypt_type"
COMMON_PARAM_KEYS.add(P_ENCRYPT_TYPE)

P_TIMESTAMP = "timestamp"
COMMON_PARAM_KEYS.add(P_TIMESTAMP)

P_VERSION = "version"
COMMON_PARAM_KEYS.add(P_VERSION)

P_NOTIFY_URL = "notify_url"
COMMON_PARAM_KEYS.add(P_NOTIFY_URL)

P_RETURN_URL = "return_url"
COMMON_PARAM_KEYS.add(P_RETURN_URL)

P_AUTH_TOKEN = "auth_token"
COMMON_PARAM_KEYS.add(P_AUTH_TOKEN)

P_APP_AUTH_TOKEN = "app_auth_token"
COMMON_PARAM_KEYS.add(P_APP_AUTH_TOKEN)

P_BIZ_CONTENT = "biz_content"




#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.BudgetVO import BudgetVO
from alipay.aop.api.domain.LoanTerm import LoanTerm
from alipay.aop.api.domain.RepayPlanTermVO import RepayPlanTermVO


class LoanApplyBudgetVO(object):

    def __init__(self):
        self._apply_amt = None
        self._apply_date = None
        self._apply_receipt_no = None
        self._budget = None
        self._current_term = None
        self._current_term_repay_date = None
        self._loan_term = None
        self._repay_plan_term_list = None

    @property
    def apply_amt(self):
        return self._apply_amt

    @apply_amt.setter
    def apply_amt(self, value):
        self._apply_amt = value
    @property
    def apply_date(self):
        return self._apply_date

    @apply_date.setter
    def apply_date(self, value):
        self._apply_date = value
    @property
    def apply_receipt_no(self):
        return self._apply_receipt_no

    @apply_receipt_no.setter
    def apply_receipt_no(self, value):
        self._apply_receipt_no = value
    @property
    def budget(self):
        return self._budget

    @budget.setter
    def budget(self, value):
        if isinstance(value, BudgetVO):
            self._budget = value
        else:
            self._budget = BudgetVO.from_alipay_dict(value)
    @property
    def current_term(self):
        return self._current_term

    @current_term.setter
    def current_term(self, value):
        self._current_term = value
    @property
    def current_term_repay_date(self):
        return self._current_term_repay_date

    @current_term_repay_date.setter
    def current_term_repay_date(self, value):
        self._current_term_repay_date = value
    @property
    def loan_term(self):
        return self._loan_term

    @loan_term.setter
    def loan_term(self, value):
        if isinstance(value, LoanTerm):
            self._loan_term = value
        else:
            self._loan_term = LoanTerm.from_alipay_dict(value)
    @property
    def repay_plan_term_list(self):
        return self._repay_plan_term_list

    @repay_plan_term_list.setter
    def repay_plan_term_list(self, value):
        if isinstance(value, list):
            self._repay_plan_term_list = list()
            for i in value:
                if isinstance(i, RepayPlanTermVO):
                    self._repay_plan_term_list.append(i)
                else:
                    self._repay_plan_term_list.append(RepayPlanTermVO.from_alipay_dict(i))


    def to_alipay_dict(self):
        params = dict()
        if self.apply_amt:
            if hasattr(self.apply_amt, 'to_alipay_dict'):
                params['apply_amt'] = self.apply_amt.to_alipay_dict()
            else:
                params['apply_amt'] = self.apply_amt
        if self.apply_date:
            if hasattr(self.apply_date, 'to_alipay_dict'):
                params['apply_date'] = self.apply_date.to_alipay_dict()
            else:
                params['apply_date'] = self.apply_date
        if self.apply_receipt_no:
            if hasattr(self.apply_receipt_no, 'to_alipay_dict'):
                params['apply_receipt_no'] = self.apply_receipt_no.to_alipay_dict()
            else:
                params['apply_receipt_no'] = self.apply_receipt_no
        if self.budget:
            if hasattr(self.budget, 'to_alipay_dict'):
                params['budget'] = self.budget.to_alipay_dict()
            else:
                params['budget'] = self.budget
        if self.current_term:
            if hasattr(self.current_term, 'to_alipay_dict'):
                params['current_term'] = self.current_term.to_alipay_dict()
            else:
                params['current_term'] = self.current_term
        if self.current_term_repay_date:
            if hasattr(self.current_term_repay_date, 'to_alipay_dict'):
                params['current_term_repay_date'] = self.current_term_repay_date.to_alipay_dict()
            else:
                params['current_term_repay_date'] = self.current_term_repay_date
        if self.loan_term:
            if hasattr(self.loan_term, 'to_alipay_dict'):
                params['loan_term'] = self.loan_term.to_alipay_dict()
            else:
                params['loan_term'] = self.loan_term
        if self.repay_plan_term_list:
            if isinstance(self.repay_plan_term_list, list):
                for i in range(0, len(self.repay_plan_term_list)):
                    element = self.repay_plan_term_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.repay_plan_term_list[i] = element.to_alipay_dict()
            if hasattr(self.repay_plan_term_list, 'to_alipay_dict'):
                params['repay_plan_term_list'] = self.repay_plan_term_list.to_alipay_dict()
            else:
                params['repay_plan_term_list'] = self.repay_plan_term_list
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = LoanApplyBudgetVO()
        if 'apply_amt' in d:
            o.apply_amt = d['apply_amt']
        if 'apply_date' in d:
            o.apply_date = d['apply_date']
        if 'apply_receipt_no' in d:
            o.apply_receipt_no = d['apply_receipt_no']
        if 'budget' in d:
            o.budget = d['budget']
        if 'current_term' in d:
            o.current_term = d['current_term']
        if 'current_term_repay_date' in d:
            o.current_term_repay_date = d['current_term_repay_date']
        if 'loan_term' in d:
            o.loan_term = d['loan_term']
        if 'repay_plan_term_list' in d:
            o.repay_plan_term_list = d['repay_plan_term_list']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayEbppInvoiceResultGetModel(object):

    def __init__(self):
        self._apply_id = None
        self._order_id = None
        self._payee_register_no = None
        self._platform_code = None
        self._platform_user_id = None

    @property
    def apply_id(self):
        return self._apply_id

    @apply_id.setter
    def apply_id(self, value):
        self._apply_id = value
    @property
    def order_id(self):
        return self._order_id

    @order_id.setter
    def order_id(self, value):
        self._order_id = value
    @property
    def payee_register_no(self):
        return self._payee_register_no

    @payee_register_no.setter
    def payee_register_no(self, value):
        self._payee_register_no = value
    @property
    def platform_code(self):
        return self._platform_code

    @platform_code.setter
    def platform_code(self, value):
        self._platform_code = value
    @property
    def platform_user_id(self):
        return self._platform_user_id

    @platform_user_id.setter
    def platform_user_id(self, value):
        self._platform_user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.apply_id:
            if hasattr(self.apply_id, 'to_alipay_dict'):
                params['apply_id'] = self.apply_id.to_alipay_dict()
            else:
                params['apply_id'] = self.apply_id
        if self.order_id:
            if hasattr(self.order_id, 'to_alipay_dict'):
                params['order_id'] = self.order_id.to_alipay_dict()
            else:
                params['order_id'] = self.order_id
        if self.payee_register_no:
            if hasattr(self.payee_register_no, 'to_alipay_dict'):
                params['payee_register_no'] = self.payee_register_no.to_alipay_dict()
            else:
                params['payee_register_no'] = self.payee_register_no
        if self.platform_code:
            if hasattr(self.platform_code, 'to_alipay_dict'):
                params['platform_code'] = self.platform_code.to_alipay_dict()
            else:
                params['platform_code'] = self.platform_code
        if self.platform_user_id:
            if hasattr(self.platform_user_id, 'to_alipay_dict'):
                params['platform_user_id'] = self.platform_user_id.to_alipay_dict()
            else:
                params['platform_user_id'] = self.platform_user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayEbppInvoiceResultGetModel()
        if 'apply_id' in d:
            o.apply_id = d['apply_id']
        if 'order_id' in d:
            o.order_id = d['order_id']
        if 'payee_register_no' in d:
            o.payee_register_no = d['payee_register_no']
        if 'platform_code' in d:
            o.platform_code = d['platform_code']
        if 'platform_user_id' in d:
            o.platform_user_id = d['platform_user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOpenMiniInnerappPluginuseconfigOnlineModel(object):

    def __init__(self):
        self._app_origin = None
        self._bundle_id = None
        self._mini_app_id = None
        self._plugin_dev_version = None
        self._plugin_id = None

    @property
    def app_origin(self):
        return self._app_origin

    @app_origin.setter
    def app_origin(self, value):
        self._app_origin = value
    @property
    def bundle_id(self):
        return self._bundle_id

    @bundle_id.setter
    def bundle_id(self, value):
        self._bundle_id = value
    @property
    def mini_app_id(self):
        return self._mini_app_id

    @mini_app_id.setter
    def mini_app_id(self, value):
        self._mini_app_id = value
    @property
    def plugin_dev_version(self):
        return self._plugin_dev_version

    @plugin_dev_version.setter
    def plugin_dev_version(self, value):
        self._plugin_dev_version = value
    @property
    def plugin_id(self):
        return self._plugin_id

    @plugin_id.setter
    def plugin_id(self, value):
        self._plugin_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.app_origin:
            if hasattr(self.app_origin, 'to_alipay_dict'):
                params['app_origin'] = self.app_origin.to_alipay_dict()
            else:
                params['app_origin'] = self.app_origin
        if self.bundle_id:
            if hasattr(self.bundle_id, 'to_alipay_dict'):
                params['bundle_id'] = self.bundle_id.to_alipay_dict()
            else:
                params['bundle_id'] = self.bundle_id
        if self.mini_app_id:
            if hasattr(self.mini_app_id, 'to_alipay_dict'):
                params['mini_app_id'] = self.mini_app_id.to_alipay_dict()
            else:
                params['mini_app_id'] = self.mini_app_id
        if self.plugin_dev_version:
            if hasattr(self.plugin_dev_version, 'to_alipay_dict'):
                params['plugin_dev_version'] = self.plugin_dev_version.to_alipay_dict()
            else:
                params['plugin_dev_version'] = self.plugin_dev_version
        if self.plugin_id:
            if hasattr(self.plugin_id, 'to_alipay_dict'):
                params['plugin_id'] = self.plugin_id.to_alipay_dict()
            else:
                params['plugin_id'] = self.plugin_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenMiniInnerappPluginuseconfigOnlineModel()
        if 'app_origin' in d:
            o.app_origin = d['app_origin']
        if 'bundle_id' in d:
            o.bundle_id = d['bundle_id']
        if 'mini_app_id' in d:
            o.mini_app_id = d['mini_app_id']
        if 'plugin_dev_version' in d:
            o.plugin_dev_version = d['plugin_dev_version']
        if 'plugin_id' in d:
            o.plugin_id = d['plugin_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class SignExtendInfo(object):

    def __init__(self):
        self._isv_pid = None
        self._scene = None

    @property
    def isv_pid(self):
        return self._isv_pid

    @isv_pid.setter
    def isv_pid(self, value):
        self._isv_pid = value
    @property
    def scene(self):
        return self._scene

    @scene.setter
    def scene(self, value):
        self._scene = value


    def to_alipay_dict(self):
        params = dict()
        if self.isv_pid:
            if hasattr(self.isv_pid, 'to_alipay_dict'):
                params['isv_pid'] = self.isv_pid.to_alipay_dict()
            else:
                params['isv_pid'] = self.isv_pid
        if self.scene:
            if hasattr(self.scene, 'to_alipay_dict'):
                params['scene'] = self.scene.to_alipay_dict()
            else:
                params['scene'] = self.scene
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = SignExtendInfo()
        if 'isv_pid' in d:
            o.isv_pid = d['isv_pid']
        if 'scene' in d:
            o.scene = d['scene']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayCommerceYuntaskHunterGetModel(object):

    def __init__(self):
        self._hunter_id = None
        self._merchant_pid = None
        self._shop_id = None
        self._task_id = None
        self._task_template_id = None

    @property
    def hunter_id(self):
        return self._hunter_id

    @hunter_id.setter
    def hunter_id(self, value):
        self._hunter_id = value
    @property
    def merchant_pid(self):
        return self._merchant_pid

    @merchant_pid.setter
    def merchant_pid(self, value):
        self._merchant_pid = value
    @property
    def shop_id(self):
        return self._shop_id

    @shop_id.setter
    def shop_id(self, value):
        self._shop_id = value
    @property
    def task_id(self):
        return self._task_id

    @task_id.setter
    def task_id(self, value):
        self._task_id = value
    @property
    def task_template_id(self):
        return self._task_template_id

    @task_template_id.setter
    def task_template_id(self, value):
        self._task_template_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.hunter_id:
            if hasattr(self.hunter_id, 'to_alipay_dict'):
                params['hunter_id'] = self.hunter_id.to_alipay_dict()
            else:
                params['hunter_id'] = self.hunter_id
        if self.merchant_pid:
            if hasattr(self.merchant_pid, 'to_alipay_dict'):
                params['merchant_pid'] = self.merchant_pid.to_alipay_dict()
            else:
                params['merchant_pid'] = self.merchant_pid
        if self.shop_id:
            if hasattr(self.shop_id, 'to_alipay_dict'):
                params['shop_id'] = self.shop_id.to_alipay_dict()
            else:
                params['shop_id'] = self.shop_id
        if self.task_id:
            if hasattr(self.task_id, 'to_alipay_dict'):
                params['task_id'] = self.task_id.to_alipay_dict()
            else:
                params['task_id'] = self.task_id
        if self.task_template_id:
            if hasattr(self.task_template_id, 'to_alipay_dict'):
                params['task_template_id'] = self.task_template_id.to_alipay_dict()
            else:
                params['task_template_id'] = self.task_template_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceYuntaskHunterGetModel()
        if 'hunter_id' in d:
            o.hunter_id = d['hunter_id']
        if 'merchant_pid' in d:
            o.merchant_pid = d['merchant_pid']
        if 'shop_id' in d:
            o.shop_id = d['shop_id']
        if 'task_id' in d:
            o.task_id = d['task_id']
        if 'task_template_id' in d:
            o.task_template_id = d['task_template_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.AccTransDetail import AccTransDetail


class AlipayFundBatchTransferModel(object):

    def __init__(self):
        self._acc_detail_list = None
        self._batch_no = None
        self._billing_address = None
        self._biz_code = None
        self._biz_scene = None
        self._extend_params = None
        self._pay_retry = None
        self._payer_account = None
        self._payer_account_type = None
        self._payment_currency = None
        self._product_code = None
        self._request_value_time = None
        self._sign_principal = None
        self._total_count = None
        self._total_trans_amount = None
        self._total_trans_currency = None

    @property
    def acc_detail_list(self):
        return self._acc_detail_list

    @acc_detail_list.setter
    def acc_detail_list(self, value):
        if isinstance(value, list):
            self._acc_detail_list = list()
            for i in value:
                if isinstance(i, AccTransDetail):
                    self._acc_detail_list.append(i)
                else:
                    self._acc_detail_list.append(AccTransDetail.from_alipay_dict(i))
    @property
    def batch_no(self):
        return self._batch_no

    @batch_no.setter
    def batch_no(self, value):
        self._batch_no = value
    @property
    def billing_address(self):
        return self._billing_address

    @billing_address.setter
    def billing_address(self, value):
        self._billing_address = value
    @property
    def biz_code(self):
        return self._biz_code

    @biz_code.setter
    def biz_code(self, value):
        self._biz_code = value
    @property
    def biz_scene(self):
        return self._biz_scene

    @biz_scene.setter
    def biz_scene(self, value):
        self._biz_scene = value
    @property
    def extend_params(self):
        return self._extend_params

    @extend_params.setter
    def extend_params(self, value):
        self._extend_params = value
    @property
    def pay_retry(self):
        return self._pay_retry

    @pay_retry.setter
    def pay_retry(self, value):
        self._pay_retry = value
    @property
    def payer_account(self):
        return self._payer_account

    @payer_account.setter
    def payer_account(self, value):
        self._payer_account = value
    @property
    def payer_account_type(self):
        return self._payer_account_type

    @payer_account_type.setter
    def payer_account_type(self, value):
        self._payer_account_type = value
    @property
    def payment_currency(self):
        return self._payment_currency

    @payment_currency.setter
    def payment_currency(self, value):
        self._payment_currency = value
    @property
    def product_code(self):
        return self._product_code

    @product_code.setter
    def product_code(self, value):
        self._product_code = value
    @property
    def request_value_time(self):
        return self._request_value_time

    @request_value_time.setter
    def request_value_time(self, value):
        self._request_value_time = value
    @property
    def sign_principal(self):
        return self._sign_principal

    @sign_principal.setter
    def sign_principal(self, value):
        self._sign_principal = value
    @property
    def total_count(self):
        return self._total_count

    @total_count.setter
    def total_count(self, value):
        self._total_count = value
    @property
    def total_trans_amount(self):
        return self._total_trans_amount

    @total_trans_amount.setter
    def total_trans_amount(self, value):
        self._total_trans_amount = value
    @property
    def total_trans_currency(self):
        return self._total_trans_currency

    @total_trans_currency.setter
    def total_trans_currency(self, value):
        self._total_trans_currency = value


    def to_alipay_dict(self):
        params = dict()
        if self.acc_detail_list:
            if isinstance(self.acc_detail_list, list):
                for i in range(0, len(self.acc_detail_list)):
                    element = self.acc_detail_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.acc_detail_list[i] = element.to_alipay_dict()
            if hasattr(self.acc_detail_list, 'to_alipay_dict'):
                params['acc_detail_list'] = self.acc_detail_list.to_alipay_dict()
            else:
                params['acc_detail_list'] = self.acc_detail_list
        if self.batch_no:
            if hasattr(self.batch_no, 'to_alipay_dict'):
                params['batch_no'] = self.batch_no.to_alipay_dict()
            else:
                params['batch_no'] = self.batch_no
        if self.billing_address:
            if hasattr(self.billing_address, 'to_alipay_dict'):
                params['billing_address'] = self.billing_address.to_alipay_dict()
            else:
                params['billing_address'] = self.billing_address
        if self.biz_code:
            if hasattr(self.biz_code, 'to_alipay_dict'):
                params['biz_code'] = self.biz_code.to_alipay_dict()
            else:
                params['biz_code'] = self.biz_code
        if self.biz_scene:
            if hasattr(self.biz_scene, 'to_alipay_dict'):
                params['biz_scene'] = self.biz_scene.to_alipay_dict()
            else:
                params['biz_scene'] = self.biz_scene
        if self.extend_params:
            if hasattr(self.extend_params, 'to_alipay_dict'):
                params['extend_params'] = self.extend_params.to_alipay_dict()
            else:
                params['extend_params'] = self.extend_params
        if self.pay_retry:
            if hasattr(self.pay_retry, 'to_alipay_dict'):
                params['pay_retry'] = self.pay_retry.to_alipay_dict()
            else:
                params['pay_retry'] = self.pay_retry
        if self.payer_account:
            if hasattr(self.payer_account, 'to_alipay_dict'):
                params['payer_account'] = self.payer_account.to_alipay_dict()
            else:
                params['payer_account'] = self.payer_account
        if self.payer_account_type:
            if hasattr(self.payer_account_type, 'to_alipay_dict'):
                params['payer_account_type'] = self.payer_account_type.to_alipay_dict()
            else:
                params['payer_account_type'] = self.payer_account_type
        if self.payment_currency:
            if hasattr(self.payment_currency, 'to_alipay_dict'):
                params['payment_currency'] = self.payment_currency.to_alipay_dict()
            else:
                params['payment_currency'] = self.payment_currency
        if self.product_code:
            if hasattr(self.product_code, 'to_alipay_dict'):
                params['product_code'] = self.product_code.to_alipay_dict()
            else:
                params['product_code'] = self.product_code
        if self.request_value_time:
            if hasattr(self.request_value_time, 'to_alipay_dict'):
                params['request_value_time'] = self.request_value_time.to_alipay_dict()
            else:
                params['request_value_time'] = self.request_value_time
        if self.sign_principal:
            if hasattr(self.sign_principal, 'to_alipay_dict'):
                params['sign_principal'] = self.sign_principal.to_alipay_dict()
            else:
                params['sign_principal'] = self.sign_principal
        if self.total_count:
            if hasattr(self.total_count, 'to_alipay_dict'):
                params['total_count'] = self.total_count.to_alipay_dict()
            else:
                params['total_count'] = self.total_count
        if self.total_trans_amount:
            if hasattr(self.total_trans_amount, 'to_alipay_dict'):
                params['total_trans_amount'] = self.total_trans_amount.to_alipay_dict()
            else:
                params['total_trans_amount'] = self.total_trans_amount
        if self.total_trans_currency:
            if hasattr(self.total_trans_currency, 'to_alipay_dict'):
                params['total_trans_currency'] = self.total_trans_currency.to_alipay_dict()
            else:
                params['total_trans_currency'] = self.total_trans_currency
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayFundBatchTransferModel()
        if 'acc_detail_list' in d:
            o.acc_detail_list = d['acc_detail_list']
        if 'batch_no' in d:
            o.batch_no = d['batch_no']
        if 'billing_address' in d:
            o.billing_address = d['billing_address']
        if 'biz_code' in d:
            o.biz_code = d['biz_code']
        if 'biz_scene' in d:
            o.biz_scene = d['biz_scene']
        if 'extend_params' in d:
            o.extend_params = d['extend_params']
        if 'pay_retry' in d:
            o.pay_retry = d['pay_retry']
        if 'payer_account' in d:
            o.payer_account = d['payer_account']
        if 'payer_account_type' in d:
            o.payer_account_type = d['payer_account_type']
        if 'payment_currency' in d:
            o.payment_currency = d['payment_currency']
        if 'product_code' in d:
            o.product_code = d['product_code']
        if 'request_value_time' in d:
            o.request_value_time = d['request_value_time']
        if 'sign_principal' in d:
            o.sign_principal = d['sign_principal']
        if 'total_count' in d:
            o.total_count = d['total_count']
        if 'total_trans_amount' in d:
            o.total_trans_amount = d['total_trans_amount']
        if 'total_trans_currency' in d:
            o.total_trans_currency = d['total_trans_currency']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.FundPlanDTO import FundPlanDTO


class AlipayFundJointaccountDepositplanDetailQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayFundJointaccountDepositplanDetailQueryResponse, self).__init__()
        self._fund_plan_list = None

    @property
    def fund_plan_list(self):
        return self._fund_plan_list

    @fund_plan_list.setter
    def fund_plan_list(self, value):
        if isinstance(value, list):
            self._fund_plan_list = list()
            for i in value:
                if isinstance(i, FundPlanDTO):
                    self._fund_plan_list.append(i)
                else:
                    self._fund_plan_list.append(FundPlanDTO.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(AlipayFundJointaccountDepositplanDetailQueryResponse, self).parse_response_content(response_content)
        if 'fund_plan_list' in response:
            self.fund_plan_list = response['fund_plan_list']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class TaskDetailInfo(object):

    def __init__(self):
        self._applied_point = None
        self._indicator_point_map = None
        self._point_status = None
        self._task_code = None
        self._task_current_indicator = None
        self._task_desc = None
        self._task_end_time = None
        self._task_icon_url = None
        self._task_introduction_url = None
        self._task_name = None
        self._task_start_time = None
        self._task_status = None
        self._task_target_indicator = None

    @property
    def applied_point(self):
        return self._applied_point

    @applied_point.setter
    def applied_point(self, value):
        self._applied_point = value
    @property
    def indicator_point_map(self):
        return self._indicator_point_map

    @indicator_point_map.setter
    def indicator_point_map(self, value):
        self._indicator_point_map = value
    @property
    def point_status(self):
        return self._point_status

    @point_status.setter
    def point_status(self, value):
        self._point_status = value
    @property
    def task_code(self):
        return self._task_code

    @task_code.setter
    def task_code(self, value):
        self._task_code = value
    @property
    def task_current_indicator(self):
        return self._task_current_indicator

    @task_current_indicator.setter
    def task_current_indicator(self, value):
        self._task_current_indicator = value
    @property
    def task_desc(self):
        return self._task_desc

    @task_desc.setter
    def task_desc(self, value):
        self._task_desc = value
    @property
    def task_end_time(self):
        return self._task_end_time

    @task_end_time.setter
    def task_end_time(self, value):
        self._task_end_time = value
    @property
    def task_icon_url(self):
        return self._task_icon_url

    @task_icon_url.setter
    def task_icon_url(self, value):
        self._task_icon_url = value
    @property
    def task_introduction_url(self):
        return self._task_introduction_url

    @task_introduction_url.setter
    def task_introduction_url(self, value):
        self._task_introduction_url = value
    @property
    def task_name(self):
        return self._task_name

    @task_name.setter
    def task_name(self, value):
        self._task_name = value
    @property
    def task_start_time(self):
        return self._task_start_time

    @task_start_time.setter
    def task_start_time(self, value):
        self._task_start_time = value
    @property
    def task_status(self):
        return self._task_status

    @task_status.setter
    def task_status(self, value):
        self._task_status = value
    @property
    def task_target_indicator(self):
        return self._task_target_indicator

    @task_target_indicator.setter
    def task_target_indicator(self, value):
        self._task_target_indicator = value


    def to_alipay_dict(self):
        params = dict()
        if self.applied_point:
            if hasattr(self.applied_point, 'to_alipay_dict'):
                params['applied_point'] = self.applied_point.to_alipay_dict()
            else:
                params['applied_point'] = self.applied_point
        if self.indicator_point_map:
            if hasattr(self.indicator_point_map, 'to_alipay_dict'):
                params['indicator_point_map'] = self.indicator_point_map.to_alipay_dict()
            else:
                params['indicator_point_map'] = self.indicator_point_map
        if self.point_status:
            if hasattr(self.point_status, 'to_alipay_dict'):
                params['point_status'] = self.point_status.to_alipay_dict()
            else:
                params['point_status'] = self.point_status
        if self.task_code:
            if hasattr(self.task_code, 'to_alipay_dict'):
                params['task_code'] = self.task_code.to_alipay_dict()
            else:
                params['task_code'] = self.task_code
        if self.task_current_indicator:
            if hasattr(self.task_current_indicator, 'to_alipay_dict'):
                params['task_current_indicator'] = self.task_current_indicator.to_alipay_dict()
            else:
                params['task_current_indicator'] = self.task_current_indicator
        if self.task_desc:
            if hasattr(self.task_desc, 'to_alipay_dict'):
                params['task_desc'] = self.task_desc.to_alipay_dict()
            else:
                params['task_desc'] = self.task_desc
        if self.task_end_time:
            if hasattr(self.task_end_time, 'to_alipay_dict'):
                params['task_end_time'] = self.task_end_time.to_alipay_dict()
            else:
                params['task_end_time'] = self.task_end_time
        if self.task_icon_url:
            if hasattr(self.task_icon_url, 'to_alipay_dict'):
                params['task_icon_url'] = self.task_icon_url.to_alipay_dict()
            else:
                params['task_icon_url'] = self.task_icon_url
        if self.task_introduction_url:
            if hasattr(self.task_introduction_url, 'to_alipay_dict'):
                params['task_introduction_url'] = self.task_introduction_url.to_alipay_dict()
            else:
                params['task_introduction_url'] = self.task_introduction_url
        if self.task_name:
            if hasattr(self.task_name, 'to_alipay_dict'):
                params['task_name'] = self.task_name.to_alipay_dict()
            else:
                params['task_name'] = self.task_name
        if self.task_start_time:
            if hasattr(self.task_start_time, 'to_alipay_dict'):
                params['task_start_time'] = self.task_start_time.to_alipay_dict()
            else:
                params['task_start_time'] = self.task_start_time
        if self.task_status:
            if hasattr(self.task_status, 'to_alipay_dict'):
                params['task_status'] = self.task_status.to_alipay_dict()
            else:
                params['task_status'] = self.task_status
        if self.task_target_indicator:
            if hasattr(self.task_target_indicator, 'to_alipay_dict'):
                params['task_target_indicator'] = self.task_target_indicator.to_alipay_dict()
            else:
                params['task_target_indicator'] = self.task_target_indicator
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = TaskDetailInfo()
        if 'applied_point' in d:
            o.applied_point = d['applied_point']
        if 'indicator_point_map' in d:
            o.indicator_point_map = d['indicator_point_map']
        if 'point_status' in d:
            o.point_status = d['point_status']
        if 'task_code' in d:
            o.task_code = d['task_code']
        if 'task_current_indicator' in d:
            o.task_current_indicator = d['task_current_indicator']
        if 'task_desc' in d:
            o.task_desc = d['task_desc']
        if 'task_end_time' in d:
            o.task_end_time = d['task_end_time']
        if 'task_icon_url' in d:
            o.task_icon_url = d['task_icon_url']
        if 'task_introduction_url' in d:
            o.task_introduction_url = d['task_introduction_url']
        if 'task_name' in d:
            o.task_name = d['task_name']
        if 'task_start_time' in d:
            o.task_start_time = d['task_start_time']
        if 'task_status' in d:
            o.task_status = d['task_status']
        if 'task_target_indicator' in d:
            o.task_target_indicator = d['task_target_indicator']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class BudgetInfo(object):

    def __init__(self):
        self._budget_total = None
        self._budget_type = None
        self._sub_budget_dimension = None
        self._sub_value = None

    @property
    def budget_total(self):
        return self._budget_total

    @budget_total.setter
    def budget_total(self, value):
        self._budget_total = value
    @property
    def budget_type(self):
        return self._budget_type

    @budget_type.setter
    def budget_type(self, value):
        self._budget_type = value
    @property
    def sub_budget_dimension(self):
        return self._sub_budget_dimension

    @sub_budget_dimension.setter
    def sub_budget_dimension(self, value):
        self._sub_budget_dimension = value
    @property
    def sub_value(self):
        return self._sub_value

    @sub_value.setter
    def sub_value(self, value):
        self._sub_value = value


    def to_alipay_dict(self):
        params = dict()
        if self.budget_total:
            if hasattr(self.budget_total, 'to_alipay_dict'):
                params['budget_total'] = self.budget_total.to_alipay_dict()
            else:
                params['budget_total'] = self.budget_total
        if self.budget_type:
            if hasattr(self.budget_type, 'to_alipay_dict'):
                params['budget_type'] = self.budget_type.to_alipay_dict()
            else:
                params['budget_type'] = self.budget_type
        if self.sub_budget_dimension:
            if hasattr(self.sub_budget_dimension, 'to_alipay_dict'):
                params['sub_budget_dimension'] = self.sub_budget_dimension.to_alipay_dict()
            else:
                params['sub_budget_dimension'] = self.sub_budget_dimension
        if self.sub_value:
            if hasattr(self.sub_value, 'to_alipay_dict'):
                params['sub_value'] = self.sub_value.to_alipay_dict()
            else:
                params['sub_value'] = self.sub_value
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = BudgetInfo()
        if 'budget_total' in d:
            o.budget_total = d['budget_total']
        if 'budget_type' in d:
            o.budget_type = d['budget_type']
        if 'sub_budget_dimension' in d:
            o.sub_budget_dimension = d['sub_budget_dimension']
        if 'sub_value' in d:
            o.sub_value = d['sub_value']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOpenAppXwbsssQueryModel(object):

    def __init__(self):
        self._a = None
        self._b = None
        self._c = None
        self._effect_date = None

    @property
    def a(self):
        return self._a

    @a.setter
    def a(self, value):
        self._a = value
    @property
    def b(self):
        return self._b

    @b.setter
    def b(self, value):
        self._b = value
    @property
    def c(self):
        return self._c

    @c.setter
    def c(self, value):
        if isinstance(value, list):
            self._c = list()
            for i in value:
                self._c.append(i)
    @property
    def effect_date(self):
        return self._effect_date

    @effect_date.setter
    def effect_date(self, value):
        self._effect_date = value


    def to_alipay_dict(self):
        params = dict()
        if self.a:
            if hasattr(self.a, 'to_alipay_dict'):
                params['a'] = self.a.to_alipay_dict()
            else:
                params['a'] = self.a
        if self.b:
            if hasattr(self.b, 'to_alipay_dict'):
                params['b'] = self.b.to_alipay_dict()
            else:
                params['b'] = self.b
        if self.c:
            if isinstance(self.c, list):
                for i in range(0, len(self.c)):
                    element = self.c[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.c[i] = element.to_alipay_dict()
            if hasattr(self.c, 'to_alipay_dict'):
                params['c'] = self.c.to_alipay_dict()
            else:
                params['c'] = self.c
        if self.effect_date:
            if hasattr(self.effect_date, 'to_alipay_dict'):
                params['effect_date'] = self.effect_date.to_alipay_dict()
            else:
                params['effect_date'] = self.effect_date
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenAppXwbsssQueryModel()
        if 'a' in d:
            o.a = d['a']
        if 'b' in d:
            o.b = d['b']
        if 'c' in d:
            o.c = d['c']
        if 'effect_date' in d:
            o.effect_date = d['effect_date']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.PrizeConfig import PrizeConfig


class AlipayMarketingCampaignPrizepoolPrizeQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayMarketingCampaignPrizepoolPrizeQueryResponse, self).__init__()
        self._prize_config = None

    @property
    def prize_config(self):
        return self._prize_config

    @prize_config.setter
    def prize_config(self, value):
        if isinstance(value, PrizeConfig):
            self._prize_config = value
        else:
            self._prize_config = PrizeConfig.from_alipay_dict(value)

    def parse_response_content(self, response_content):
        response = super(AlipayMarketingCampaignPrizepoolPrizeQueryResponse, self).parse_response_content(response_content)
        if 'prize_config' in response:
            self.prize_config = response['prize_config']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class DeviceBehaviorLogResponse(object):

    def __init__(self):
        self._behavior_type = None
        self._log_content = None
        self._log_time = None

    @property
    def behavior_type(self):
        return self._behavior_type

    @behavior_type.setter
    def behavior_type(self, value):
        self._behavior_type = value
    @property
    def log_content(self):
        return self._log_content

    @log_content.setter
    def log_content(self, value):
        self._log_content = value
    @property
    def log_time(self):
        return self._log_time

    @log_time.setter
    def log_time(self, value):
        self._log_time = value


    def to_alipay_dict(self):
        params = dict()
        if self.behavior_type:
            if hasattr(self.behavior_type, 'to_alipay_dict'):
                params['behavior_type'] = self.behavior_type.to_alipay_dict()
            else:
                params['behavior_type'] = self.behavior_type
        if self.log_content:
            if hasattr(self.log_content, 'to_alipay_dict'):
                params['log_content'] = self.log_content.to_alipay_dict()
            else:
                params['log_content'] = self.log_content
        if self.log_time:
            if hasattr(self.log_time, 'to_alipay_dict'):
                params['log_time'] = self.log_time.to_alipay_dict()
            else:
                params['log_time'] = self.log_time
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = DeviceBehaviorLogResponse()
        if 'behavior_type' in d:
            o.behavior_type = d['behavior_type']
        if 'log_content' in d:
            o.log_content = d['log_content']
        if 'log_time' in d:
            o.log_time = d['log_time']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.MiniAppPluginReference import MiniAppPluginReference
from alipay.aop.api.domain.SubPackage import SubPackage


class AlipayOpenMiniInnerversionPreviewUploadModel(object):

    def __init__(self):
        self._build_js_permission = None
        self._build_pkg_url = None
        self._build_plugin_url = None
        self._bundle_id = None
        self._extend_info = None
        self._inst_code = None
        self._main_url = None
        self._mini_app_id = None
        self._new_build_pkg_url = None
        self._new_build_plugin_url = None
        self._plugin_refs = None
        self._scene = None
        self._sub_packages = None

    @property
    def build_js_permission(self):
        return self._build_js_permission

    @build_js_permission.setter
    def build_js_permission(self, value):
        self._build_js_permission = value
    @property
    def build_pkg_url(self):
        return self._build_pkg_url

    @build_pkg_url.setter
    def build_pkg_url(self, value):
        self._build_pkg_url = value
    @property
    def build_plugin_url(self):
        return self._build_plugin_url

    @build_plugin_url.setter
    def build_plugin_url(self, value):
        self._build_plugin_url = value
    @property
    def bundle_id(self):
        return self._bundle_id

    @bundle_id.setter
    def bundle_id(self, value):
        self._bundle_id = value
    @property
    def extend_info(self):
        return self._extend_info

    @extend_info.setter
    def extend_info(self, value):
        self._extend_info = value
    @property
    def inst_code(self):
        return self._inst_code

    @inst_code.setter
    def inst_code(self, value):
        self._inst_code = value
    @property
    def main_url(self):
        return self._main_url

    @main_url.setter
    def main_url(self, value):
        self._main_url = value
    @property
    def mini_app_id(self):
        return self._mini_app_id

    @mini_app_id.setter
    def mini_app_id(self, value):
        self._mini_app_id = value
    @property
    def new_build_pkg_url(self):
        return self._new_build_pkg_url

    @new_build_pkg_url.setter
    def new_build_pkg_url(self, value):
        self._new_build_pkg_url = value
    @property
    def new_build_plugin_url(self):
        return self._new_build_plugin_url

    @new_build_plugin_url.setter
    def new_build_plugin_url(self, value):
        self._new_build_plugin_url = value
    @property
    def plugin_refs(self):
        return self._plugin_refs

    @plugin_refs.setter
    def plugin_refs(self, value):
        if isinstance(value, list):
            self._plugin_refs = list()
            for i in value:
                if isinstance(i, MiniAppPluginReference):
                    self._plugin_refs.append(i)
                else:
                    self._plugin_refs.append(MiniAppPluginReference.from_alipay_dict(i))
    @property
    def scene(self):
        return self._scene

    @scene.setter
    def scene(self, value):
        self._scene = value
    @property
    def sub_packages(self):
        return self._sub_packages

    @sub_packages.setter
    def sub_packages(self, value):
        if isinstance(value, list):
            self._sub_packages = list()
            for i in value:
                if isinstance(i, SubPackage):
                    self._sub_packages.append(i)
                else:
                    self._sub_packages.append(SubPackage.from_alipay_dict(i))


    def to_alipay_dict(self):
        params = dict()
        if self.build_js_permission:
            if hasattr(self.build_js_permission, 'to_alipay_dict'):
                params['build_js_permission'] = self.build_js_permission.to_alipay_dict()
            else:
                params['build_js_permission'] = self.build_js_permission
        if self.build_pkg_url:
            if hasattr(self.build_pkg_url, 'to_alipay_dict'):
                params['build_pkg_url'] = self.build_pkg_url.to_alipay_dict()
            else:
                params['build_pkg_url'] = self.build_pkg_url
        if self.build_plugin_url:
            if hasattr(self.build_plugin_url, 'to_alipay_dict'):
                params['build_plugin_url'] = self.build_plugin_url.to_alipay_dict()
            else:
                params['build_plugin_url'] = self.build_plugin_url
        if self.bundle_id:
            if hasattr(self.bundle_id, 'to_alipay_dict'):
                params['bundle_id'] = self.bundle_id.to_alipay_dict()
            else:
                params['bundle_id'] = self.bundle_id
        if self.extend_info:
            if hasattr(self.extend_info, 'to_alipay_dict'):
                params['extend_info'] = self.extend_info.to_alipay_dict()
            else:
                params['extend_info'] = self.extend_info
        if self.inst_code:
            if hasattr(self.inst_code, 'to_alipay_dict'):
                params['inst_code'] = self.inst_code.to_alipay_dict()
            else:
                params['inst_code'] = self.inst_code
        if self.main_url:
            if hasattr(self.main_url, 'to_alipay_dict'):
                params['main_url'] = self.main_url.to_alipay_dict()
            else:
                params['main_url'] = self.main_url
        if self.mini_app_id:
            if hasattr(self.mini_app_id, 'to_alipay_dict'):
                params['mini_app_id'] = self.mini_app_id.to_alipay_dict()
            else:
                params['mini_app_id'] = self.mini_app_id
        if self.new_build_pkg_url:
            if hasattr(self.new_build_pkg_url, 'to_alipay_dict'):
                params['new_build_pkg_url'] = self.new_build_pkg_url.to_alipay_dict()
            else:
                params['new_build_pkg_url'] = self.new_build_pkg_url
        if self.new_build_plugin_url:
            if hasattr(self.new_build_plugin_url, 'to_alipay_dict'):
                params['new_build_plugin_url'] = self.new_build_plugin_url.to_alipay_dict()
            else:
                params['new_build_plugin_url'] = self.new_build_plugin_url
        if self.plugin_refs:
            if isinstance(self.plugin_refs, list):
                for i in range(0, len(self.plugin_refs)):
                    element = self.plugin_refs[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.plugin_refs[i] = element.to_alipay_dict()
            if hasattr(self.plugin_refs, 'to_alipay_dict'):
                params['plugin_refs'] = self.plugin_refs.to_alipay_dict()
            else:
                params['plugin_refs'] = self.plugin_refs
        if self.scene:
            if hasattr(self.scene, 'to_alipay_dict'):
                params['scene'] = self.scene.to_alipay_dict()
            else:
                params['scene'] = self.scene
        if self.sub_packages:
            if isinstance(self.sub_packages, list):
                for i in range(0, len(self.sub_packages)):
                    element = self.sub_packages[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.sub_packages[i] = element.to_alipay_dict()
            if hasattr(self.sub_packages, 'to_alipay_dict'):
                params['sub_packages'] = self.sub_packages.to_alipay_dict()
            else:
                params['sub_packages'] = self.sub_packages
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenMiniInnerversionPreviewUploadModel()
        if 'build_js_permission' in d:
            o.build_js_permission = d['build_js_permission']
        if 'build_pkg_url' in d:
            o.build_pkg_url = d['build_pkg_url']
        if 'build_plugin_url' in d:
            o.build_plugin_url = d['build_plugin_url']
        if 'bundle_id' in d:
            o.bundle_id = d['bundle_id']
        if 'extend_info' in d:
            o.extend_info = d['extend_info']
        if 'inst_code' in d:
            o.inst_code = d['inst_code']
        if 'main_url' in d:
            o.main_url = d['main_url']
        if 'mini_app_id' in d:
            o.mini_app_id = d['mini_app_id']
        if 'new_build_pkg_url' in d:
            o.new_build_pkg_url = d['new_build_pkg_url']
        if 'new_build_plugin_url' in d:
            o.new_build_plugin_url = d['new_build_plugin_url']
        if 'plugin_refs' in d:
            o.plugin_refs = d['plugin_refs']
        if 'scene' in d:
            o.scene = d['scene']
        if 'sub_packages' in d:
            o.sub_packages = d['sub_packages']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayCommerceOperationGamemarketingBenefitVerifyResponse(AlipayResponse):

    def __init__(self):
        super(AlipayCommerceOperationGamemarketingBenefitVerifyResponse, self).__init__()
        self._voucher_verify_status = None

    @property
    def voucher_verify_status(self):
        return self._voucher_verify_status

    @voucher_verify_status.setter
    def voucher_verify_status(self, value):
        self._voucher_verify_status = value

    def parse_response_content(self, response_content):
        response = super(AlipayCommerceOperationGamemarketingBenefitVerifyResponse, self).parse_response_content(response_content)
        if 'voucher_verify_status' in response:
            self.voucher_verify_status = response['voucher_verify_status']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipaySecurityRiskReconfirmVerificatecallbackSendModel(object):

    def __init__(self):
        self._account = None
        self._app_code = None
        self._extend_param = None
        self._identify_id = None
        self._reauth_type = None
        self._reconfirm_result = None
        self._scene_code = None
        self._um_id = None
        self._um_id_token = None
        self._user_id = None

    @property
    def account(self):
        return self._account

    @account.setter
    def account(self, value):
        self._account = value
    @property
    def app_code(self):
        return self._app_code

    @app_code.setter
    def app_code(self, value):
        self._app_code = value
    @property
    def extend_param(self):
        return self._extend_param

    @extend_param.setter
    def extend_param(self, value):
        self._extend_param = value
    @property
    def identify_id(self):
        return self._identify_id

    @identify_id.setter
    def identify_id(self, value):
        self._identify_id = value
    @property
    def reauth_type(self):
        return self._reauth_type

    @reauth_type.setter
    def reauth_type(self, value):
        self._reauth_type = value
    @property
    def reconfirm_result(self):
        return self._reconfirm_result

    @reconfirm_result.setter
    def reconfirm_result(self, value):
        self._reconfirm_result = value
    @property
    def scene_code(self):
        return self._scene_code

    @scene_code.setter
    def scene_code(self, value):
        self._scene_code = value
    @property
    def um_id(self):
        return self._um_id

    @um_id.setter
    def um_id(self, value):
        self._um_id = value
    @property
    def um_id_token(self):
        return self._um_id_token

    @um_id_token.setter
    def um_id_token(self, value):
        self._um_id_token = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.account:
            if hasattr(self.account, 'to_alipay_dict'):
                params['account'] = self.account.to_alipay_dict()
            else:
                params['account'] = self.account
        if self.app_code:
            if hasattr(self.app_code, 'to_alipay_dict'):
                params['app_code'] = self.app_code.to_alipay_dict()
            else:
                params['app_code'] = self.app_code
        if self.extend_param:
            if hasattr(self.extend_param, 'to_alipay_dict'):
                params['extend_param'] = self.extend_param.to_alipay_dict()
            else:
                params['extend_param'] = self.extend_param
        if self.identify_id:
            if hasattr(self.identify_id, 'to_alipay_dict'):
                params['identify_id'] = self.identify_id.to_alipay_dict()
            else:
                params['identify_id'] = self.identify_id
        if self.reauth_type:
            if hasattr(self.reauth_type, 'to_alipay_dict'):
                params['reauth_type'] = self.reauth_type.to_alipay_dict()
            else:
                params['reauth_type'] = self.reauth_type
        if self.reconfirm_result:
            if hasattr(self.reconfirm_result, 'to_alipay_dict'):
                params['reconfirm_result'] = self.reconfirm_result.to_alipay_dict()
            else:
                params['reconfirm_result'] = self.reconfirm_result
        if self.scene_code:
            if hasattr(self.scene_code, 'to_alipay_dict'):
                params['scene_code'] = self.scene_code.to_alipay_dict()
            else:
                params['scene_code'] = self.scene_code
        if self.um_id:
            if hasattr(self.um_id, 'to_alipay_dict'):
                params['um_id'] = self.um_id.to_alipay_dict()
            else:
                params['um_id'] = self.um_id
        if self.um_id_token:
            if hasattr(self.um_id_token, 'to_alipay_dict'):
                params['um_id_token'] = self.um_id_token.to_alipay_dict()
            else:
                params['um_id_token'] = self.um_id_token
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipaySecurityRiskReconfirmVerificatecallbackSendModel()
        if 'account' in d:
            o.account = d['account']
        if 'app_code' in d:
            o.app_code = d['app_code']
        if 'extend_param' in d:
            o.extend_param = d['extend_param']
        if 'identify_id' in d:
            o.identify_id = d['identify_id']
        if 'reauth_type' in d:
            o.reauth_type = d['reauth_type']
        if 'reconfirm_result' in d:
            o.reconfirm_result = d['reconfirm_result']
        if 'scene_code' in d:
            o.scene_code = d['scene_code']
        if 'um_id' in d:
            o.um_id = d['um_id']
        if 'um_id_token' in d:
            o.um_id_token = d['um_id_token']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayUserGroupshoppingNewbieQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayUserGroupshoppingNewbieQueryResponse, self).__init__()
        self._access = None
        self._message = None
        self._reason = None
        self._user_id_list = None

    @property
    def access(self):
        return self._access

    @access.setter
    def access(self, value):
        self._access = value
    @property
    def message(self):
        return self._message

    @message.setter
    def message(self, value):
        self._message = value
    @property
    def reason(self):
        return self._reason

    @reason.setter
    def reason(self, value):
        self._reason = value
    @property
    def user_id_list(self):
        return self._user_id_list

    @user_id_list.setter
    def user_id_list(self, value):
        if isinstance(value, list):
            self._user_id_list = list()
            for i in value:
                self._user_id_list.append(i)

    def parse_response_content(self, response_content):
        response = super(AlipayUserGroupshoppingNewbieQueryResponse, self).parse_response_content(response_content)
        if 'access' in response:
            self.access = response['access']
        if 'message' in response:
            self.message = response['message']
        if 'reason' in response:
            self.reason = response['reason']
        if 'user_id_list' in response:
            self.user_id_list = response['user_id_list']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class IntelligentGuideTradeDetail(object):

    def __init__(self):
        self._card_type = None
        self._customer_source = None
        self._customer_type = None
        self._date = None
        self._fifth_recommendation = None
        self._first_category = None
        self._first_recommendation = None
        self._fourth_recommendation = None
        self._guide_record_id = None
        self._item_name = None
        self._mobile = None
        self._original_price = None
        self._payment_type = None
        self._price = None
        self._second_category = None
        self._second_recommendation = None
        self._service_staff = None
        self._third_recommendation = None

    @property
    def card_type(self):
        return self._card_type

    @card_type.setter
    def card_type(self, value):
        self._card_type = value
    @property
    def customer_source(self):
        return self._customer_source

    @customer_source.setter
    def customer_source(self, value):
        self._customer_source = value
    @property
    def customer_type(self):
        return self._customer_type

    @customer_type.setter
    def customer_type(self, value):
        self._customer_type = value
    @property
    def date(self):
        return self._date

    @date.setter
    def date(self, value):
        self._date = value
    @property
    def fifth_recommendation(self):
        return self._fifth_recommendation

    @fifth_recommendation.setter
    def fifth_recommendation(self, value):
        self._fifth_recommendation = value
    @property
    def first_category(self):
        return self._first_category

    @first_category.setter
    def first_category(self, value):
        self._first_category = value
    @property
    def first_recommendation(self):
        return self._first_recommendation

    @first_recommendation.setter
    def first_recommendation(self, value):
        self._first_recommendation = value
    @property
    def fourth_recommendation(self):
        return self._fourth_recommendation

    @fourth_recommendation.setter
    def fourth_recommendation(self, value):
        self._fourth_recommendation = value
    @property
    def guide_record_id(self):
        return self._guide_record_id

    @guide_record_id.setter
    def guide_record_id(self, value):
        self._guide_record_id = value
    @property
    def item_name(self):
        return self._item_name

    @item_name.setter
    def item_name(self, value):
        self._item_name = value
    @property
    def mobile(self):
        return self._mobile

    @mobile.setter
    def mobile(self, value):
        self._mobile = value
    @property
    def original_price(self):
        return self._original_price

    @original_price.setter
    def original_price(self, value):
        self._original_price = value
    @property
    def payment_type(self):
        return self._payment_type

    @payment_type.setter
    def payment_type(self, value):
        self._payment_type = value
    @property
    def price(self):
        return self._price

    @price.setter
    def price(self, value):
        self._price = value
    @property
    def second_category(self):
        return self._second_category

    @second_category.setter
    def second_category(self, value):
        self._second_category = value
    @property
    def second_recommendation(self):
        return self._second_recommendation

    @second_recommendation.setter
    def second_recommendation(self, value):
        self._second_recommendation = value
    @property
    def service_staff(self):
        return self._service_staff

    @service_staff.setter
    def service_staff(self, value):
        self._service_staff = value
    @property
    def third_recommendation(self):
        return self._third_recommendation

    @third_recommendation.setter
    def third_recommendation(self, value):
        self._third_recommendation = value


    def to_alipay_dict(self):
        params = dict()
        if self.card_type:
            if hasattr(self.card_type, 'to_alipay_dict'):
                params['card_type'] = self.card_type.to_alipay_dict()
            else:
                params['card_type'] = self.card_type
        if self.customer_source:
            if hasattr(self.customer_source, 'to_alipay_dict'):
                params['customer_source'] = self.customer_source.to_alipay_dict()
            else:
                params['customer_source'] = self.customer_source
        if self.customer_type:
            if hasattr(self.customer_type, 'to_alipay_dict'):
                params['customer_type'] = self.customer_type.to_alipay_dict()
            else:
                params['customer_type'] = self.customer_type
        if self.date:
            if hasattr(self.date, 'to_alipay_dict'):
                params['date'] = self.date.to_alipay_dict()
            else:
                params['date'] = self.date
        if self.fifth_recommendation:
            if hasattr(self.fifth_recommendation, 'to_alipay_dict'):
                params['fifth_recommendation'] = self.fifth_recommendation.to_alipay_dict()
            else:
                params['fifth_recommendation'] = self.fifth_recommendation
        if self.first_category:
            if hasattr(self.first_category, 'to_alipay_dict'):
                params['first_category'] = self.first_category.to_alipay_dict()
            else:
                params['first_category'] = self.first_category
        if self.first_recommendation:
            if hasattr(self.first_recommendation, 'to_alipay_dict'):
                params['first_recommendation'] = self.first_recommendation.to_alipay_dict()
            else:
                params['first_recommendation'] = self.first_recommendation
        if self.fourth_recommendation:
            if hasattr(self.fourth_recommendation, 'to_alipay_dict'):
                params['fourth_recommendation'] = self.fourth_recommendation.to_alipay_dict()
            else:
                params['fourth_recommendation'] = self.fourth_recommendation
        if self.guide_record_id:
            if hasattr(self.guide_record_id, 'to_alipay_dict'):
                params['guide_record_id'] = self.guide_record_id.to_alipay_dict()
            else:
                params['guide_record_id'] = self.guide_record_id
        if self.item_name:
            if hasattr(self.item_name, 'to_alipay_dict'):
                params['item_name'] = self.item_name.to_alipay_dict()
            else:
                params['item_name'] = self.item_name
        if self.mobile:
            if hasattr(self.mobile, 'to_alipay_dict'):
                params['mobile'] = self.mobile.to_alipay_dict()
            else:
                params['mobile'] = self.mobile
        if self.original_price:
            if hasattr(self.original_price, 'to_alipay_dict'):
                params['original_price'] = self.original_price.to_alipay_dict()
            else:
                params['original_price'] = self.original_price
        if self.payment_type:
            if hasattr(self.payment_type, 'to_alipay_dict'):
                params['payment_type'] = self.payment_type.to_alipay_dict()
            else:
                params['payment_type'] = self.payment_type
        if self.price:
            if hasattr(self.price, 'to_alipay_dict'):
                params['price'] = self.price.to_alipay_dict()
            else:
                params['price'] = self.price
        if self.second_category:
            if hasattr(self.second_category, 'to_alipay_dict'):
                params['second_category'] = self.second_category.to_alipay_dict()
            else:
                params['second_category'] = self.second_category
        if self.second_recommendation:
            if hasattr(self.second_recommendation, 'to_alipay_dict'):
                params['second_recommendation'] = self.second_recommendation.to_alipay_dict()
            else:
                params['second_recommendation'] = self.second_recommendation
        if self.service_staff:
            if hasattr(self.service_staff, 'to_alipay_dict'):
                params['service_staff'] = self.service_staff.to_alipay_dict()
            else:
                params['service_staff'] = self.service_staff
        if self.third_recommendation:
            if hasattr(self.third_recommendation, 'to_alipay_dict'):
                params['third_recommendation'] = self.third_recommendation.to_alipay_dict()
            else:
                params['third_recommendation'] = self.third_recommendation
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = IntelligentGuideTradeDetail()
        if 'card_type' in d:
            o.card_type = d['card_type']
        if 'customer_source' in d:
            o.customer_source = d['customer_source']
        if 'customer_type' in d:
            o.customer_type = d['customer_type']
        if 'date' in d:
            o.date = d['date']
        if 'fifth_recommendation' in d:
            o.fifth_recommendation = d['fifth_recommendation']
        if 'first_category' in d:
            o.first_category = d['first_category']
        if 'first_recommendation' in d:
            o.first_recommendation = d['first_recommendation']
        if 'fourth_recommendation' in d:
            o.fourth_recommendation = d['fourth_recommendation']
        if 'guide_record_id' in d:
            o.guide_record_id = d['guide_record_id']
        if 'item_name' in d:
            o.item_name = d['item_name']
        if 'mobile' in d:
            o.mobile = d['mobile']
        if 'original_price' in d:
            o.original_price = d['original_price']
        if 'payment_type' in d:
            o.payment_type = d['payment_type']
        if 'price' in d:
            o.price = d['price']
        if 'second_category' in d:
            o.second_category = d['second_category']
        if 'second_recommendation' in d:
            o.second_recommendation = d['second_recommendation']
        if 'service_staff' in d:
            o.service_staff = d['service_staff']
        if 'third_recommendation' in d:
            o.third_recommendation = d['third_recommendation']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.TuitionISVAgentInfoDTO import TuitionISVAgentInfoDTO


class AlipayOverseasOpenPreorderCancelModel(object):

    def __init__(self):
        self._agent_info = None
        self._pre_order_id = None

    @property
    def agent_info(self):
        return self._agent_info

    @agent_info.setter
    def agent_info(self, value):
        if isinstance(value, TuitionISVAgentInfoDTO):
            self._agent_info = value
        else:
            self._agent_info = TuitionISVAgentInfoDTO.from_alipay_dict(value)
    @property
    def pre_order_id(self):
        return self._pre_order_id

    @pre_order_id.setter
    def pre_order_id(self, value):
        self._pre_order_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.agent_info:
            if hasattr(self.agent_info, 'to_alipay_dict'):
                params['agent_info'] = self.agent_info.to_alipay_dict()
            else:
                params['agent_info'] = self.agent_info
        if self.pre_order_id:
            if hasattr(self.pre_order_id, 'to_alipay_dict'):
                params['pre_order_id'] = self.pre_order_id.to_alipay_dict()
            else:
                params['pre_order_id'] = self.pre_order_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOverseasOpenPreorderCancelModel()
        if 'agent_info' in d:
            o.agent_info = d['agent_info']
        if 'pre_order_id' in d:
            o.pre_order_id = d['pre_order_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ExternalPoiInfo(object):

    def __init__(self):
        self._address = None
        self._entity_id = None
        self._entity_type = None
        self._id = None
        self._latitude = None
        self._longitude = None
        self._memo = None
        self._poi = None

    @property
    def address(self):
        return self._address

    @address.setter
    def address(self, value):
        self._address = value
    @property
    def entity_id(self):
        return self._entity_id

    @entity_id.setter
    def entity_id(self, value):
        self._entity_id = value
    @property
    def entity_type(self):
        return self._entity_type

    @entity_type.setter
    def entity_type(self, value):
        self._entity_type = value
    @property
    def id(self):
        return self._id

    @id.setter
    def id(self, value):
        self._id = value
    @property
    def latitude(self):
        return self._latitude

    @latitude.setter
    def latitude(self, value):
        self._latitude = value
    @property
    def longitude(self):
        return self._longitude

    @longitude.setter
    def longitude(self, value):
        self._longitude = value
    @property
    def memo(self):
        return self._memo

    @memo.setter
    def memo(self, value):
        self._memo = value
    @property
    def poi(self):
        return self._poi

    @poi.setter
    def poi(self, value):
        self._poi = value


    def to_alipay_dict(self):
        params = dict()
        if self.address:
            if hasattr(self.address, 'to_alipay_dict'):
                params['address'] = self.address.to_alipay_dict()
            else:
                params['address'] = self.address
        if self.entity_id:
            if hasattr(self.entity_id, 'to_alipay_dict'):
                params['entity_id'] = self.entity_id.to_alipay_dict()
            else:
                params['entity_id'] = self.entity_id
        if self.entity_type:
            if hasattr(self.entity_type, 'to_alipay_dict'):
                params['entity_type'] = self.entity_type.to_alipay_dict()
            else:
                params['entity_type'] = self.entity_type
        if self.id:
            if hasattr(self.id, 'to_alipay_dict'):
                params['id'] = self.id.to_alipay_dict()
            else:
                params['id'] = self.id
        if self.latitude:
            if hasattr(self.latitude, 'to_alipay_dict'):
                params['latitude'] = self.latitude.to_alipay_dict()
            else:
                params['latitude'] = self.latitude
        if self.longitude:
            if hasattr(self.longitude, 'to_alipay_dict'):
                params['longitude'] = self.longitude.to_alipay_dict()
            else:
                params['longitude'] = self.longitude
        if self.memo:
            if hasattr(self.memo, 'to_alipay_dict'):
                params['memo'] = self.memo.to_alipay_dict()
            else:
                params['memo'] = self.memo
        if self.poi:
            if hasattr(self.poi, 'to_alipay_dict'):
                params['poi'] = self.poi.to_alipay_dict()
            else:
                params['poi'] = self.poi
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ExternalPoiInfo()
        if 'address' in d:
            o.address = d['address']
        if 'entity_id' in d:
            o.entity_id = d['entity_id']
        if 'entity_type' in d:
            o.entity_type = d['entity_type']
        if 'id' in d:
            o.id = d['id']
        if 'latitude' in d:
            o.latitude = d['latitude']
        if 'longitude' in d:
            o.longitude = d['longitude']
        if 'memo' in d:
            o.memo = d['memo']
        if 'poi' in d:
            o.poi = d['poi']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayOpenPublicXwbtestabcdBatchqueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOpenPublicXwbtestabcdBatchqueryResponse, self).__init__()
        self._b = None

    @property
    def b(self):
        return self._b

    @b.setter
    def b(self, value):
        self._b = value

    def parse_response_content(self, response_content):
        response = super(AlipayOpenPublicXwbtestabcdBatchqueryResponse, self).parse_response_content(response_content)
        if 'b' in response:
            self.b = response['b']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.GavintestNewLeveaOne import GavintestNewLeveaOne


class ZhimaOpenAppDesSendModel(object):

    def __init__(self):
        self._com = None
        self._test = None

    @property
    def com(self):
        return self._com

    @com.setter
    def com(self, value):
        if isinstance(value, GavintestNewLeveaOne):
            self._com = value
        else:
            self._com = GavintestNewLeveaOne.from_alipay_dict(value)
    @property
    def test(self):
        return self._test

    @test.setter
    def test(self, value):
        self._test = value


    def to_alipay_dict(self):
        params = dict()
        if self.com:
            if hasattr(self.com, 'to_alipay_dict'):
                params['com'] = self.com.to_alipay_dict()
            else:
                params['com'] = self.com
        if self.test:
            if hasattr(self.test, 'to_alipay_dict'):
                params['test'] = self.test.to_alipay_dict()
            else:
                params['test'] = self.test
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ZhimaOpenAppDesSendModel()
        if 'com' in d:
            o.com = d['com']
        if 'test' in d:
            o.test = d['test']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class DeviceApplyOrderItemModel(object):

    def __init__(self):
        self._apply_amount = None
        self._item_id = None
        self._item_name = None
        self._model_number = None

    @property
    def apply_amount(self):
        return self._apply_amount

    @apply_amount.setter
    def apply_amount(self, value):
        self._apply_amount = value
    @property
    def item_id(self):
        return self._item_id

    @item_id.setter
    def item_id(self, value):
        self._item_id = value
    @property
    def item_name(self):
        return self._item_name

    @item_name.setter
    def item_name(self, value):
        self._item_name = value
    @property
    def model_number(self):
        return self._model_number

    @model_number.setter
    def model_number(self, value):
        self._model_number = value


    def to_alipay_dict(self):
        params = dict()
        if self.apply_amount:
            if hasattr(self.apply_amount, 'to_alipay_dict'):
                params['apply_amount'] = self.apply_amount.to_alipay_dict()
            else:
                params['apply_amount'] = self.apply_amount
        if self.item_id:
            if hasattr(self.item_id, 'to_alipay_dict'):
                params['item_id'] = self.item_id.to_alipay_dict()
            else:
                params['item_id'] = self.item_id
        if self.item_name:
            if hasattr(self.item_name, 'to_alipay_dict'):
                params['item_name'] = self.item_name.to_alipay_dict()
            else:
                params['item_name'] = self.item_name
        if self.model_number:
            if hasattr(self.model_number, 'to_alipay_dict'):
                params['model_number'] = self.model_number.to_alipay_dict()
            else:
                params['model_number'] = self.model_number
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = DeviceApplyOrderItemModel()
        if 'apply_amount' in d:
            o.apply_amount = d['apply_amount']
        if 'item_id' in d:
            o.item_id = d['item_id']
        if 'item_name' in d:
            o.item_name = d['item_name']
        if 'model_number' in d:
            o.model_number = d['model_number']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AftFinsecureRiskplusSecurityPolicyQueryResponse(AlipayResponse):

    def __init__(self):
        super(AftFinsecureRiskplusSecurityPolicyQueryResponse, self).__init__()
        self._level = None
        self._security_id = None
        self._security_result = None
        self._success = None
        self._template_code = None
        self._template_desc = None
        self._verify_id = None
        self._verify_url = None

    @property
    def level(self):
        return self._level

    @level.setter
    def level(self, value):
        self._level = value
    @property
    def security_id(self):
        return self._security_id

    @security_id.setter
    def security_id(self, value):
        self._security_id = value
    @property
    def security_result(self):
        return self._security_result

    @security_result.setter
    def security_result(self, value):
        self._security_result = value
    @property
    def success(self):
        return self._success

    @success.setter
    def success(self, value):
        self._success = value
    @property
    def template_code(self):
        return self._template_code

    @template_code.setter
    def template_code(self, value):
        self._template_code = value
    @property
    def template_desc(self):
        return self._template_desc

    @template_desc.setter
    def template_desc(self, value):
        self._template_desc = value
    @property
    def verify_id(self):
        return self._verify_id

    @verify_id.setter
    def verify_id(self, value):
        self._verify_id = value
    @property
    def verify_url(self):
        return self._verify_url

    @verify_url.setter
    def verify_url(self, value):
        self._verify_url = value

    def parse_response_content(self, response_content):
        response = super(AftFinsecureRiskplusSecurityPolicyQueryResponse, self).parse_response_content(response_content)
        if 'level' in response:
            self.level = response['level']
        if 'security_id' in response:
            self.security_id = response['security_id']
        if 'security_result' in response:
            self.security_result = response['security_result']
        if 'success' in response:
            self.success = response['success']
        if 'template_code' in response:
            self.template_code = response['template_code']
        if 'template_desc' in response:
            self.template_desc = response['template_desc']
        if 'verify_id' in response:
            self.verify_id = response['verify_id']
        if 'verify_url' in response:
            self.verify_url = response['verify_url']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.MemberCardPayEffectiveItemRule import MemberCardPayEffectiveItemRule
from alipay.aop.api.domain.MemberCardPayEffectiveShopRule import MemberCardPayEffectiveShopRule


class MemberCardPayEffectiveRule(object):

    def __init__(self):
        self._item_rule = None
        self._shop_rules = None
        self._smids = None

    @property
    def item_rule(self):
        return self._item_rule

    @item_rule.setter
    def item_rule(self, value):
        if isinstance(value, MemberCardPayEffectiveItemRule):
            self._item_rule = value
        else:
            self._item_rule = MemberCardPayEffectiveItemRule.from_alipay_dict(value)
    @property
    def shop_rules(self):
        return self._shop_rules

    @shop_rules.setter
    def shop_rules(self, value):
        if isinstance(value, list):
            self._shop_rules = list()
            for i in value:
                if isinstance(i, MemberCardPayEffectiveShopRule):
                    self._shop_rules.append(i)
                else:
                    self._shop_rules.append(MemberCardPayEffectiveShopRule.from_alipay_dict(i))
    @property
    def smids(self):
        return self._smids

    @smids.setter
    def smids(self, value):
        if isinstance(value, list):
            self._smids = list()
            for i in value:
                self._smids.append(i)


    def to_alipay_dict(self):
        params = dict()
        if self.item_rule:
            if hasattr(self.item_rule, 'to_alipay_dict'):
                params['item_rule'] = self.item_rule.to_alipay_dict()
            else:
                params['item_rule'] = self.item_rule
        if self.shop_rules:
            if isinstance(self.shop_rules, list):
                for i in range(0, len(self.shop_rules)):
                    element = self.shop_rules[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.shop_rules[i] = element.to_alipay_dict()
            if hasattr(self.shop_rules, 'to_alipay_dict'):
                params['shop_rules'] = self.shop_rules.to_alipay_dict()
            else:
                params['shop_rules'] = self.shop_rules
        if self.smids:
            if isinstance(self.smids, list):
                for i in range(0, len(self.smids)):
                    element = self.smids[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.smids[i] = element.to_alipay_dict()
            if hasattr(self.smids, 'to_alipay_dict'):
                params['smids'] = self.smids.to_alipay_dict()
            else:
                params['smids'] = self.smids
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = MemberCardPayEffectiveRule()
        if 'item_rule' in d:
            o.item_rule = d['item_rule']
        if 'shop_rules' in d:
            o.shop_rules = d['shop_rules']
        if 'smids' in d:
            o.smids = d['smids']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayMerchantServiceconsultFeedbackSubmitModel(object):

    def __init__(self):
        self._consult_event_id = None
        self._reply_content = None
        self._reply_images = None

    @property
    def consult_event_id(self):
        return self._consult_event_id

    @consult_event_id.setter
    def consult_event_id(self, value):
        self._consult_event_id = value
    @property
    def reply_content(self):
        return self._reply_content

    @reply_content.setter
    def reply_content(self, value):
        self._reply_content = value
    @property
    def reply_images(self):
        return self._reply_images

    @reply_images.setter
    def reply_images(self, value):
        self._reply_images = value


    def to_alipay_dict(self):
        params = dict()
        if self.consult_event_id:
            if hasattr(self.consult_event_id, 'to_alipay_dict'):
                params['consult_event_id'] = self.consult_event_id.to_alipay_dict()
            else:
                params['consult_event_id'] = self.consult_event_id
        if self.reply_content:
            if hasattr(self.reply_content, 'to_alipay_dict'):
                params['reply_content'] = self.reply_content.to_alipay_dict()
            else:
                params['reply_content'] = self.reply_content
        if self.reply_images:
            if hasattr(self.reply_images, 'to_alipay_dict'):
                params['reply_images'] = self.reply_images.to_alipay_dict()
            else:
                params['reply_images'] = self.reply_images
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayMerchantServiceconsultFeedbackSubmitModel()
        if 'consult_event_id' in d:
            o.consult_event_id = d['consult_event_id']
        if 'reply_content' in d:
            o.reply_content = d['reply_content']
        if 'reply_images' in d:
            o.reply_images = d['reply_images']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.InvoiceLineInfoOrder import InvoiceLineInfoOrder
from alipay.aop.api.domain.UserInvoiceInfoOrder import UserInvoiceInfoOrder


class AlipayBossFncGfsettleprodNobillinvoiceApplyModel(object):

    def __init__(self):
        self._audit_staff = None
        self._biz_id = None
        self._biz_no = None
        self._can_link = None
        self._inst_id = None
        self._invoice_line_list = None
        self._invoice_material = None
        self._invoice_note = None
        self._invoice_type = None
        self._memo = None
        self._operator = None
        self._operator_domain_name = None
        self._order_way = None
        self._user_invoice_info = None

    @property
    def audit_staff(self):
        return self._audit_staff

    @audit_staff.setter
    def audit_staff(self, value):
        self._audit_staff = value
    @property
    def biz_id(self):
        return self._biz_id

    @biz_id.setter
    def biz_id(self, value):
        self._biz_id = value
    @property
    def biz_no(self):
        return self._biz_no

    @biz_no.setter
    def biz_no(self, value):
        self._biz_no = value
    @property
    def can_link(self):
        return self._can_link

    @can_link.setter
    def can_link(self, value):
        self._can_link = value
    @property
    def inst_id(self):
        return self._inst_id

    @inst_id.setter
    def inst_id(self, value):
        self._inst_id = value
    @property
    def invoice_line_list(self):
        return self._invoice_line_list

    @invoice_line_list.setter
    def invoice_line_list(self, value):
        if isinstance(value, list):
            self._invoice_line_list = list()
            for i in value:
                if isinstance(i, InvoiceLineInfoOrder):
                    self._invoice_line_list.append(i)
                else:
                    self._invoice_line_list.append(InvoiceLineInfoOrder.from_alipay_dict(i))
    @property
    def invoice_material(self):
        return self._invoice_material

    @invoice_material.setter
    def invoice_material(self, value):
        self._invoice_material = value
    @property
    def invoice_note(self):
        return self._invoice_note

    @invoice_note.setter
    def invoice_note(self, value):
        self._invoice_note = value
    @property
    def invoice_type(self):
        return self._invoice_type

    @invoice_type.setter
    def invoice_type(self, value):
        self._invoice_type = value
    @property
    def memo(self):
        return self._memo

    @memo.setter
    def memo(self, value):
        self._memo = value
    @property
    def operator(self):
        return self._operator

    @operator.setter
    def operator(self, value):
        self._operator = value
    @property
    def operator_domain_name(self):
        return self._operator_domain_name

    @operator_domain_name.setter
    def operator_domain_name(self, value):
        self._operator_domain_name = value
    @property
    def order_way(self):
        return self._order_way

    @order_way.setter
    def order_way(self, value):
        self._order_way = value
    @property
    def user_invoice_info(self):
        return self._user_invoice_info

    @user_invoice_info.setter
    def user_invoice_info(self, value):
        if isinstance(value, UserInvoiceInfoOrder):
            self._user_invoice_info = value
        else:
            self._user_invoice_info = UserInvoiceInfoOrder.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.audit_staff:
            if hasattr(self.audit_staff, 'to_alipay_dict'):
                params['audit_staff'] = self.audit_staff.to_alipay_dict()
            else:
                params['audit_staff'] = self.audit_staff
        if self.biz_id:
            if hasattr(self.biz_id, 'to_alipay_dict'):
                params['biz_id'] = self.biz_id.to_alipay_dict()
            else:
                params['biz_id'] = self.biz_id
        if self.biz_no:
            if hasattr(self.biz_no, 'to_alipay_dict'):
                params['biz_no'] = self.biz_no.to_alipay_dict()
            else:
                params['biz_no'] = self.biz_no
        if self.can_link:
            if hasattr(self.can_link, 'to_alipay_dict'):
                params['can_link'] = self.can_link.to_alipay_dict()
            else:
                params['can_link'] = self.can_link
        if self.inst_id:
            if hasattr(self.inst_id, 'to_alipay_dict'):
                params['inst_id'] = self.inst_id.to_alipay_dict()
            else:
                params['inst_id'] = self.inst_id
        if self.invoice_line_list:
            if isinstance(self.invoice_line_list, list):
                for i in range(0, len(self.invoice_line_list)):
                    element = self.invoice_line_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.invoice_line_list[i] = element.to_alipay_dict()
            if hasattr(self.invoice_line_list, 'to_alipay_dict'):
                params['invoice_line_list'] = self.invoice_line_list.to_alipay_dict()
            else:
                params['invoice_line_list'] = self.invoice_line_list
        if self.invoice_material:
            if hasattr(self.invoice_material, 'to_alipay_dict'):
                params['invoice_material'] = self.invoice_material.to_alipay_dict()
            else:
                params['invoice_material'] = self.invoice_material
        if self.invoice_note:
            if hasattr(self.invoice_note, 'to_alipay_dict'):
                params['invoice_note'] = self.invoice_note.to_alipay_dict()
            else:
                params['invoice_note'] = self.invoice_note
        if self.invoice_type:
            if hasattr(self.invoice_type, 'to_alipay_dict'):
                params['invoice_type'] = self.invoice_type.to_alipay_dict()
            else:
                params['invoice_type'] = self.invoice_type
        if self.memo:
            if hasattr(self.memo, 'to_alipay_dict'):
                params['memo'] = self.memo.to_alipay_dict()
            else:
                params['memo'] = self.memo
        if self.operator:
            if hasattr(self.operator, 'to_alipay_dict'):
                params['operator'] = self.operator.to_alipay_dict()
            else:
                params['operator'] = self.operator
        if self.operator_domain_name:
            if hasattr(self.operator_domain_name, 'to_alipay_dict'):
                params['operator_domain_name'] = self.operator_domain_name.to_alipay_dict()
            else:
                params['operator_domain_name'] = self.operator_domain_name
        if self.order_way:
            if hasattr(self.order_way, 'to_alipay_dict'):
                params['order_way'] = self.order_way.to_alipay_dict()
            else:
                params['order_way'] = self.order_way
        if self.user_invoice_info:
            if hasattr(self.user_invoice_info, 'to_alipay_dict'):
                params['user_invoice_info'] = self.user_invoice_info.to_alipay_dict()
            else:
                params['user_invoice_info'] = self.user_invoice_info
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayBossFncGfsettleprodNobillinvoiceApplyModel()
        if 'audit_staff' in d:
            o.audit_staff = d['audit_staff']
        if 'biz_id' in d:
            o.biz_id = d['biz_id']
        if 'biz_no' in d:
            o.biz_no = d['biz_no']
        if 'can_link' in d:
            o.can_link = d['can_link']
        if 'inst_id' in d:
            o.inst_id = d['inst_id']
        if 'invoice_line_list' in d:
            o.invoice_line_list = d['invoice_line_list']
        if 'invoice_material' in d:
            o.invoice_material = d['invoice_material']
        if 'invoice_note' in d:
            o.invoice_note = d['invoice_note']
        if 'invoice_type' in d:
            o.invoice_type = d['invoice_type']
        if 'memo' in d:
            o.memo = d['memo']
        if 'operator' in d:
            o.operator = d['operator']
        if 'operator_domain_name' in d:
            o.operator_domain_name = d['operator_domain_name']
        if 'order_way' in d:
            o.order_way = d['order_way']
        if 'user_invoice_info' in d:
            o.user_invoice_info = d['user_invoice_info']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.OperateContext import OperateContext


class KoubeiRetailWmsPartnerQueryModel(object):

    def __init__(self):
        self._operate_context = None
        self._partner_ids = None

    @property
    def operate_context(self):
        return self._operate_context

    @operate_context.setter
    def operate_context(self, value):
        if isinstance(value, OperateContext):
            self._operate_context = value
        else:
            self._operate_context = OperateContext.from_alipay_dict(value)
    @property
    def partner_ids(self):
        return self._partner_ids

    @partner_ids.setter
    def partner_ids(self, value):
        if isinstance(value, list):
            self._partner_ids = list()
            for i in value:
                self._partner_ids.append(i)


    def to_alipay_dict(self):
        params = dict()
        if self.operate_context:
            if hasattr(self.operate_context, 'to_alipay_dict'):
                params['operate_context'] = self.operate_context.to_alipay_dict()
            else:
                params['operate_context'] = self.operate_context
        if self.partner_ids:
            if isinstance(self.partner_ids, list):
                for i in range(0, len(self.partner_ids)):
                    element = self.partner_ids[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.partner_ids[i] = element.to_alipay_dict()
            if hasattr(self.partner_ids, 'to_alipay_dict'):
                params['partner_ids'] = self.partner_ids.to_alipay_dict()
            else:
                params['partner_ids'] = self.partner_ids
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KoubeiRetailWmsPartnerQueryModel()
        if 'operate_context' in d:
            o.operate_context = d['operate_context']
        if 'partner_ids' in d:
            o.partner_ids = d['partner_ids']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayFundAuthOrderFreezeModel(object):

    def __init__(self):
        self._amount = None
        self._auth_code = None
        self._auth_code_type = None
        self._disable_pay_channels = None
        self._enable_pay_channels = None
        self._extra_param = None
        self._identity_params = None
        self._order_title = None
        self._out_order_no = None
        self._out_request_no = None
        self._pay_timeout = None
        self._payee_logon_id = None
        self._payee_user_id = None
        self._product_code = None
        self._scene_code = None
        self._settle_currency = None
        self._terminal_params = None
        self._timeout_express = None
        self._trans_currency = None

    @property
    def amount(self):
        return self._amount

    @amount.setter
    def amount(self, value):
        self._amount = value
    @property
    def auth_code(self):
        return self._auth_code

    @auth_code.setter
    def auth_code(self, value):
        self._auth_code = value
    @property
    def auth_code_type(self):
        return self._auth_code_type

    @auth_code_type.setter
    def auth_code_type(self, value):
        self._auth_code_type = value
    @property
    def disable_pay_channels(self):
        return self._disable_pay_channels

    @disable_pay_channels.setter
    def disable_pay_channels(self, value):
        self._disable_pay_channels = value
    @property
    def enable_pay_channels(self):
        return self._enable_pay_channels

    @enable_pay_channels.setter
    def enable_pay_channels(self, value):
        self._enable_pay_channels = value
    @property
    def extra_param(self):
        return self._extra_param

    @extra_param.setter
    def extra_param(self, value):
        self._extra_param = value
    @property
    def identity_params(self):
        return self._identity_params

    @identity_params.setter
    def identity_params(self, value):
        self._identity_params = value
    @property
    def order_title(self):
        return self._order_title

    @order_title.setter
    def order_title(self, value):
        self._order_title = value
    @property
    def out_order_no(self):
        return self._out_order_no

    @out_order_no.setter
    def out_order_no(self, value):
        self._out_order_no = value
    @property
    def out_request_no(self):
        return self._out_request_no

    @out_request_no.setter
    def out_request_no(self, value):
        self._out_request_no = value
    @property
    def pay_timeout(self):
        return self._pay_timeout

    @pay_timeout.setter
    def pay_timeout(self, value):
        self._pay_timeout = value
    @property
    def payee_logon_id(self):
        return self._payee_logon_id

    @payee_logon_id.setter
    def payee_logon_id(self, value):
        self._payee_logon_id = value
    @property
    def payee_user_id(self):
        return self._payee_user_id

    @payee_user_id.setter
    def payee_user_id(self, value):
        self._payee_user_id = value
    @property
    def product_code(self):
        return self._product_code

    @product_code.setter
    def product_code(self, value):
        self._product_code = value
    @property
    def scene_code(self):
        return self._scene_code

    @scene_code.setter
    def scene_code(self, value):
        self._scene_code = value
    @property
    def settle_currency(self):
        return self._settle_currency

    @settle_currency.setter
    def settle_currency(self, value):
        self._settle_currency = value
    @property
    def terminal_params(self):
        return self._terminal_params

    @terminal_params.setter
    def terminal_params(self, value):
        self._terminal_params = value
    @property
    def timeout_express(self):
        return self._timeout_express

    @timeout_express.setter
    def timeout_express(self, value):
        self._timeout_express = value
    @property
    def trans_currency(self):
        return self._trans_currency

    @trans_currency.setter
    def trans_currency(self, value):
        self._trans_currency = value


    def to_alipay_dict(self):
        params = dict()
        if self.amount:
            if hasattr(self.amount, 'to_alipay_dict'):
                params['amount'] = self.amount.to_alipay_dict()
            else:
                params['amount'] = self.amount
        if self.auth_code:
            if hasattr(self.auth_code, 'to_alipay_dict'):
                params['auth_code'] = self.auth_code.to_alipay_dict()
            else:
                params['auth_code'] = self.auth_code
        if self.auth_code_type:
            if hasattr(self.auth_code_type, 'to_alipay_dict'):
                params['auth_code_type'] = self.auth_code_type.to_alipay_dict()
            else:
                params['auth_code_type'] = self.auth_code_type
        if self.disable_pay_channels:
            if hasattr(self.disable_pay_channels, 'to_alipay_dict'):
                params['disable_pay_channels'] = self.disable_pay_channels.to_alipay_dict()
            else:
                params['disable_pay_channels'] = self.disable_pay_channels
        if self.enable_pay_channels:
            if hasattr(self.enable_pay_channels, 'to_alipay_dict'):
                params['enable_pay_channels'] = self.enable_pay_channels.to_alipay_dict()
            else:
                params['enable_pay_channels'] = self.enable_pay_channels
        if self.extra_param:
            if hasattr(self.extra_param, 'to_alipay_dict'):
                params['extra_param'] = self.extra_param.to_alipay_dict()
            else:
                params['extra_param'] = self.extra_param
        if self.identity_params:
            if hasattr(self.identity_params, 'to_alipay_dict'):
                params['identity_params'] = self.identity_params.to_alipay_dict()
            else:
                params['identity_params'] = self.identity_params
        if self.order_title:
            if hasattr(self.order_title, 'to_alipay_dict'):
                params['order_title'] = self.order_title.to_alipay_dict()
            else:
                params['order_title'] = self.order_title
        if self.out_order_no:
            if hasattr(self.out_order_no, 'to_alipay_dict'):
                params['out_order_no'] = self.out_order_no.to_alipay_dict()
            else:
                params['out_order_no'] = self.out_order_no
        if self.out_request_no:
            if hasattr(self.out_request_no, 'to_alipay_dict'):
                params['out_request_no'] = self.out_request_no.to_alipay_dict()
            else:
                params['out_request_no'] = self.out_request_no
        if self.pay_timeout:
            if hasattr(self.pay_timeout, 'to_alipay_dict'):
                params['pay_timeout'] = self.pay_timeout.to_alipay_dict()
            else:
                params['pay_timeout'] = self.pay_timeout
        if self.payee_logon_id:
            if hasattr(self.payee_logon_id, 'to_alipay_dict'):
                params['payee_logon_id'] = self.payee_logon_id.to_alipay_dict()
            else:
                params['payee_logon_id'] = self.payee_logon_id
        if self.payee_user_id:
            if hasattr(self.payee_user_id, 'to_alipay_dict'):
                params['payee_user_id'] = self.payee_user_id.to_alipay_dict()
            else:
                params['payee_user_id'] = self.payee_user_id
        if self.product_code:
            if hasattr(self.product_code, 'to_alipay_dict'):
                params['product_code'] = self.product_code.to_alipay_dict()
            else:
                params['product_code'] = self.product_code
        if self.scene_code:
            if hasattr(self.scene_code, 'to_alipay_dict'):
                params['scene_code'] = self.scene_code.to_alipay_dict()
            else:
                params['scene_code'] = self.scene_code
        if self.settle_currency:
            if hasattr(self.settle_currency, 'to_alipay_dict'):
                params['settle_currency'] = self.settle_currency.to_alipay_dict()
            else:
                params['settle_currency'] = self.settle_currency
        if self.terminal_params:
            if hasattr(self.terminal_params, 'to_alipay_dict'):
                params['terminal_params'] = self.terminal_params.to_alipay_dict()
            else:
                params['terminal_params'] = self.terminal_params
        if self.timeout_express:
            if hasattr(self.timeout_express, 'to_alipay_dict'):
                params['timeout_express'] = self.timeout_express.to_alipay_dict()
            else:
                params['timeout_express'] = self.timeout_express
        if self.trans_currency:
            if hasattr(self.trans_currency, 'to_alipay_dict'):
                params['trans_currency'] = self.trans_currency.to_alipay_dict()
            else:
                params['trans_currency'] = self.trans_currency
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayFundAuthOrderFreezeModel()
        if 'amount' in d:
            o.amount = d['amount']
        if 'auth_code' in d:
            o.auth_code = d['auth_code']
        if 'auth_code_type' in d:
            o.auth_code_type = d['auth_code_type']
        if 'disable_pay_channels' in d:
            o.disable_pay_channels = d['disable_pay_channels']
        if 'enable_pay_channels' in d:
            o.enable_pay_channels = d['enable_pay_channels']
        if 'extra_param' in d:
            o.extra_param = d['extra_param']
        if 'identity_params' in d:
            o.identity_params = d['identity_params']
        if 'order_title' in d:
            o.order_title = d['order_title']
        if 'out_order_no' in d:
            o.out_order_no = d['out_order_no']
        if 'out_request_no' in d:
            o.out_request_no = d['out_request_no']
        if 'pay_timeout' in d:
            o.pay_timeout = d['pay_timeout']
        if 'payee_logon_id' in d:
            o.payee_logon_id = d['payee_logon_id']
        if 'payee_user_id' in d:
            o.payee_user_id = d['payee_user_id']
        if 'product_code' in d:
            o.product_code = d['product_code']
        if 'scene_code' in d:
            o.scene_code = d['scene_code']
        if 'settle_currency' in d:
            o.settle_currency = d['settle_currency']
        if 'terminal_params' in d:
            o.terminal_params = d['terminal_params']
        if 'timeout_express' in d:
            o.timeout_express = d['timeout_express']
        if 'trans_currency' in d:
            o.trans_currency = d['trans_currency']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class KoubeiServindustryLeadsRecordBatchqueryModel(object):

    def __init__(self):
        self._gmt_end = None
        self._gmt_start = None
        self._page_no = None
        self._page_size = None

    @property
    def gmt_end(self):
        return self._gmt_end

    @gmt_end.setter
    def gmt_end(self, value):
        self._gmt_end = value
    @property
    def gmt_start(self):
        return self._gmt_start

    @gmt_start.setter
    def gmt_start(self, value):
        self._gmt_start = value
    @property
    def page_no(self):
        return self._page_no

    @page_no.setter
    def page_no(self, value):
        self._page_no = value
    @property
    def page_size(self):
        return self._page_size

    @page_size.setter
    def page_size(self, value):
        self._page_size = value


    def to_alipay_dict(self):
        params = dict()
        if self.gmt_end:
            if hasattr(self.gmt_end, 'to_alipay_dict'):
                params['gmt_end'] = self.gmt_end.to_alipay_dict()
            else:
                params['gmt_end'] = self.gmt_end
        if self.gmt_start:
            if hasattr(self.gmt_start, 'to_alipay_dict'):
                params['gmt_start'] = self.gmt_start.to_alipay_dict()
            else:
                params['gmt_start'] = self.gmt_start
        if self.page_no:
            if hasattr(self.page_no, 'to_alipay_dict'):
                params['page_no'] = self.page_no.to_alipay_dict()
            else:
                params['page_no'] = self.page_no
        if self.page_size:
            if hasattr(self.page_size, 'to_alipay_dict'):
                params['page_size'] = self.page_size.to_alipay_dict()
            else:
                params['page_size'] = self.page_size
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KoubeiServindustryLeadsRecordBatchqueryModel()
        if 'gmt_end' in d:
            o.gmt_end = d['gmt_end']
        if 'gmt_start' in d:
            o.gmt_start = d['gmt_start']
        if 'page_no' in d:
            o.page_no = d['page_no']
        if 'page_size' in d:
            o.page_size = d['page_size']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class SmartAddressInfo(object):

    def __init__(self):
        self._area_code = None
        self._city_code = None
        self._machine_address = None
        self._province_code = None

    @property
    def area_code(self):
        return self._area_code

    @area_code.setter
    def area_code(self, value):
        self._area_code = value
    @property
    def city_code(self):
        return self._city_code

    @city_code.setter
    def city_code(self, value):
        self._city_code = value
    @property
    def machine_address(self):
        return self._machine_address

    @machine_address.setter
    def machine_address(self, value):
        self._machine_address = value
    @property
    def province_code(self):
        return self._province_code

    @province_code.setter
    def province_code(self, value):
        self._province_code = value


    def to_alipay_dict(self):
        params = dict()
        if self.area_code:
            if hasattr(self.area_code, 'to_alipay_dict'):
                params['area_code'] = self.area_code.to_alipay_dict()
            else:
                params['area_code'] = self.area_code
        if self.city_code:
            if hasattr(self.city_code, 'to_alipay_dict'):
                params['city_code'] = self.city_code.to_alipay_dict()
            else:
                params['city_code'] = self.city_code
        if self.machine_address:
            if hasattr(self.machine_address, 'to_alipay_dict'):
                params['machine_address'] = self.machine_address.to_alipay_dict()
            else:
                params['machine_address'] = self.machine_address
        if self.province_code:
            if hasattr(self.province_code, 'to_alipay_dict'):
                params['province_code'] = self.province_code.to_alipay_dict()
            else:
                params['province_code'] = self.province_code
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = SmartAddressInfo()
        if 'area_code' in d:
            o.area_code = d['area_code']
        if 'city_code' in d:
            o.city_code = d['city_code']
        if 'machine_address' in d:
            o.machine_address = d['machine_address']
        if 'province_code' in d:
            o.province_code = d['province_code']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayDataAiserviceCloudbusTimeodGetModel(object):

    def __init__(self):
        self._app_version = None
        self._city_code = None
        self._date_type = None
        self._dest_geo = None
        self._end_date = None
        self._origin_geo_hashs = None
        self._partner_id = None
        self._start_date = None

    @property
    def app_version(self):
        return self._app_version

    @app_version.setter
    def app_version(self, value):
        self._app_version = value
    @property
    def city_code(self):
        return self._city_code

    @city_code.setter
    def city_code(self, value):
        self._city_code = value
    @property
    def date_type(self):
        return self._date_type

    @date_type.setter
    def date_type(self, value):
        self._date_type = value
    @property
    def dest_geo(self):
        return self._dest_geo

    @dest_geo.setter
    def dest_geo(self, value):
        self._dest_geo = value
    @property
    def end_date(self):
        return self._end_date

    @end_date.setter
    def end_date(self, value):
        self._end_date = value
    @property
    def origin_geo_hashs(self):
        return self._origin_geo_hashs

    @origin_geo_hashs.setter
    def origin_geo_hashs(self, value):
        if isinstance(value, list):
            self._origin_geo_hashs = list()
            for i in value:
                self._origin_geo_hashs.append(i)
    @property
    def partner_id(self):
        return self._partner_id

    @partner_id.setter
    def partner_id(self, value):
        self._partner_id = value
    @property
    def start_date(self):
        return self._start_date

    @start_date.setter
    def start_date(self, value):
        self._start_date = value


    def to_alipay_dict(self):
        params = dict()
        if self.app_version:
            if hasattr(self.app_version, 'to_alipay_dict'):
                params['app_version'] = self.app_version.to_alipay_dict()
            else:
                params['app_version'] = self.app_version
        if self.city_code:
            if hasattr(self.city_code, 'to_alipay_dict'):
                params['city_code'] = self.city_code.to_alipay_dict()
            else:
                params['city_code'] = self.city_code
        if self.date_type:
            if hasattr(self.date_type, 'to_alipay_dict'):
                params['date_type'] = self.date_type.to_alipay_dict()
            else:
                params['date_type'] = self.date_type
        if self.dest_geo:
            if hasattr(self.dest_geo, 'to_alipay_dict'):
                params['dest_geo'] = self.dest_geo.to_alipay_dict()
            else:
                params['dest_geo'] = self.dest_geo
        if self.end_date:
            if hasattr(self.end_date, 'to_alipay_dict'):
                params['end_date'] = self.end_date.to_alipay_dict()
            else:
                params['end_date'] = self.end_date
        if self.origin_geo_hashs:
            if isinstance(self.origin_geo_hashs, list):
                for i in range(0, len(self.origin_geo_hashs)):
                    element = self.origin_geo_hashs[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.origin_geo_hashs[i] = element.to_alipay_dict()
            if hasattr(self.origin_geo_hashs, 'to_alipay_dict'):
                params['origin_geo_hashs'] = self.origin_geo_hashs.to_alipay_dict()
            else:
                params['origin_geo_hashs'] = self.origin_geo_hashs
        if self.partner_id:
            if hasattr(self.partner_id, 'to_alipay_dict'):
                params['partner_id'] = self.partner_id.to_alipay_dict()
            else:
                params['partner_id'] = self.partner_id
        if self.start_date:
            if hasattr(self.start_date, 'to_alipay_dict'):
                params['start_date'] = self.start_date.to_alipay_dict()
            else:
                params['start_date'] = self.start_date
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayDataAiserviceCloudbusTimeodGetModel()
        if 'app_version' in d:
            o.app_version = d['app_version']
        if 'city_code' in d:
            o.city_code = d['city_code']
        if 'date_type' in d:
            o.date_type = d['date_type']
        if 'dest_geo' in d:
            o.dest_geo = d['dest_geo']
        if 'end_date' in d:
            o.end_date = d['end_date']
        if 'origin_geo_hashs' in d:
            o.origin_geo_hashs = d['origin_geo_hashs']
        if 'partner_id' in d:
            o.partner_id = d['partner_id']
        if 'start_date' in d:
            o.start_date = d['start_date']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ScenicAuditInfo(object):

    def __init__(self):
        self._audit_msg = None
        self._audit_status = None
        self._import_gmt_create = None
        self._outer_id_isv = None
        self._outer_id_zfb = None
        self._scenic_app_id = None
        self._scenic_id = None

    @property
    def audit_msg(self):
        return self._audit_msg

    @audit_msg.setter
    def audit_msg(self, value):
        self._audit_msg = value
    @property
    def audit_status(self):
        return self._audit_status

    @audit_status.setter
    def audit_status(self, value):
        self._audit_status = value
    @property
    def import_gmt_create(self):
        return self._import_gmt_create

    @import_gmt_create.setter
    def import_gmt_create(self, value):
        self._import_gmt_create = value
    @property
    def outer_id_isv(self):
        return self._outer_id_isv

    @outer_id_isv.setter
    def outer_id_isv(self, value):
        self._outer_id_isv = value
    @property
    def outer_id_zfb(self):
        return self._outer_id_zfb

    @outer_id_zfb.setter
    def outer_id_zfb(self, value):
        self._outer_id_zfb = value
    @property
    def scenic_app_id(self):
        return self._scenic_app_id

    @scenic_app_id.setter
    def scenic_app_id(self, value):
        self._scenic_app_id = value
    @property
    def scenic_id(self):
        return self._scenic_id

    @scenic_id.setter
    def scenic_id(self, value):
        self._scenic_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.audit_msg:
            if hasattr(self.audit_msg, 'to_alipay_dict'):
                params['audit_msg'] = self.audit_msg.to_alipay_dict()
            else:
                params['audit_msg'] = self.audit_msg
        if self.audit_status:
            if hasattr(self.audit_status, 'to_alipay_dict'):
                params['audit_status'] = self.audit_status.to_alipay_dict()
            else:
                params['audit_status'] = self.audit_status
        if self.import_gmt_create:
            if hasattr(self.import_gmt_create, 'to_alipay_dict'):
                params['import_gmt_create'] = self.import_gmt_create.to_alipay_dict()
            else:
                params['import_gmt_create'] = self.import_gmt_create
        if self.outer_id_isv:
            if hasattr(self.outer_id_isv, 'to_alipay_dict'):
                params['outer_id_isv'] = self.outer_id_isv.to_alipay_dict()
            else:
                params['outer_id_isv'] = self.outer_id_isv
        if self.outer_id_zfb:
            if hasattr(self.outer_id_zfb, 'to_alipay_dict'):
                params['outer_id_zfb'] = self.outer_id_zfb.to_alipay_dict()
            else:
                params['outer_id_zfb'] = self.outer_id_zfb
        if self.scenic_app_id:
            if hasattr(self.scenic_app_id, 'to_alipay_dict'):
                params['scenic_app_id'] = self.scenic_app_id.to_alipay_dict()
            else:
                params['scenic_app_id'] = self.scenic_app_id
        if self.scenic_id:
            if hasattr(self.scenic_id, 'to_alipay_dict'):
                params['scenic_id'] = self.scenic_id.to_alipay_dict()
            else:
                params['scenic_id'] = self.scenic_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ScenicAuditInfo()
        if 'audit_msg' in d:
            o.audit_msg = d['audit_msg']
        if 'audit_status' in d:
            o.audit_status = d['audit_status']
        if 'import_gmt_create' in d:
            o.import_gmt_create = d['import_gmt_create']
        if 'outer_id_isv' in d:
            o.outer_id_isv = d['outer_id_isv']
        if 'outer_id_zfb' in d:
            o.outer_id_zfb = d['outer_id_zfb']
        if 'scenic_app_id' in d:
            o.scenic_app_id = d['scenic_app_id']
        if 'scenic_id' in d:
            o.scenic_id = d['scenic_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.JointAccountQuotaRespDTO import JointAccountQuotaRespDTO
from alipay.aop.api.domain.AuthorizedRuleDTO import AuthorizedRuleDTO
from alipay.aop.api.domain.InviteResultDTO import InviteResultDTO
from alipay.aop.api.domain.JointAccountMemberInfoRespDTO import JointAccountMemberInfoRespDTO


class AlipayFundJointaccountDetailQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayFundJointaccountDetailQueryResponse, self).__init__()
        self._account_id = None
        self._account_name = None
        self._account_quota = None
        self._account_status = None
        self._agreement_no = None
        self._authorized_rule = None
        self._available_balance = None
        self._biz_scene = None
        self._creator_id = None
        self._creator_out_id = None
        self._freeze_balance = None
        self._invite_result_list = None
        self._member_list = None
        self._product_code = None

    @property
    def account_id(self):
        return self._account_id

    @account_id.setter
    def account_id(self, value):
        self._account_id = value
    @property
    def account_name(self):
        return self._account_name

    @account_name.setter
    def account_name(self, value):
        self._account_name = value
    @property
    def account_quota(self):
        return self._account_quota

    @account_quota.setter
    def account_quota(self, value):
        if isinstance(value, list):
            self._account_quota = list()
            for i in value:
                if isinstance(i, JointAccountQuotaRespDTO):
                    self._account_quota.append(i)
                else:
                    self._account_quota.append(JointAccountQuotaRespDTO.from_alipay_dict(i))
    @property
    def account_status(self):
        return self._account_status

    @account_status.setter
    def account_status(self, value):
        self._account_status = value
    @property
    def agreement_no(self):
        return self._agreement_no

    @agreement_no.setter
    def agreement_no(self, value):
        self._agreement_no = value
    @property
    def authorized_rule(self):
        return self._authorized_rule

    @authorized_rule.setter
    def authorized_rule(self, value):
        if isinstance(value, AuthorizedRuleDTO):
            self._authorized_rule = value
        else:
            self._authorized_rule = AuthorizedRuleDTO.from_alipay_dict(value)
    @property
    def available_balance(self):
        return self._available_balance

    @available_balance.setter
    def available_balance(self, value):
        self._available_balance = value
    @property
    def biz_scene(self):
        return self._biz_scene

    @biz_scene.setter
    def biz_scene(self, value):
        self._biz_scene = value
    @property
    def creator_id(self):
        return self._creator_id

    @creator_id.setter
    def creator_id(self, value):
        self._creator_id = value
    @property
    def creator_out_id(self):
        return self._creator_out_id

    @creator_out_id.setter
    def creator_out_id(self, value):
        self._creator_out_id = value
    @property
    def freeze_balance(self):
        return self._freeze_balance

    @freeze_balance.setter
    def freeze_balance(self, value):
        self._freeze_balance = value
    @property
    def invite_result_list(self):
        return self._invite_result_list

    @invite_result_list.setter
    def invite_result_list(self, value):
        if isinstance(value, list):
            self._invite_result_list = list()
            for i in value:
                if isinstance(i, InviteResultDTO):
                    self._invite_result_list.append(i)
                else:
                    self._invite_result_list.append(InviteResultDTO.from_alipay_dict(i))
    @property
    def member_list(self):
        return self._member_list

    @member_list.setter
    def member_list(self, value):
        if isinstance(value, list):
            self._member_list = list()
            for i in value:
                if isinstance(i, JointAccountMemberInfoRespDTO):
                    self._member_list.append(i)
                else:
                    self._member_list.append(JointAccountMemberInfoRespDTO.from_alipay_dict(i))
    @property
    def product_code(self):
        return self._product_code

    @product_code.setter
    def product_code(self, value):
        self._product_code = value

    def parse_response_content(self, response_content):
        response = super(AlipayFundJointaccountDetailQueryResponse, self).parse_response_content(response_content)
        if 'account_id' in response:
            self.account_id = response['account_id']
        if 'account_name' in response:
            self.account_name = response['account_name']
        if 'account_quota' in response:
            self.account_quota = response['account_quota']
        if 'account_status' in response:
            self.account_status = response['account_status']
        if 'agreement_no' in response:
            self.agreement_no = response['agreement_no']
        if 'authorized_rule' in response:
            self.authorized_rule = response['authorized_rule']
        if 'available_balance' in response:
            self.available_balance = response['available_balance']
        if 'biz_scene' in response:
            self.biz_scene = response['biz_scene']
        if 'creator_id' in response:
            self.creator_id = response['creator_id']
        if 'creator_out_id' in response:
            self.creator_out_id = response['creator_out_id']
        if 'freeze_balance' in response:
            self.freeze_balance = response['freeze_balance']
        if 'invite_result_list' in response:
            self.invite_result_list = response['invite_result_list']
        if 'member_list' in response:
            self.member_list = response['member_list']
        if 'product_code' in response:
            self.product_code = response['product_code']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.LifeLabel import LifeLabel


class AlipayOpenPublicLifeLabelBatchqueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOpenPublicLifeLabelBatchqueryResponse, self).__init__()
        self._labels = None

    @property
    def labels(self):
        return self._labels

    @labels.setter
    def labels(self, value):
        if isinstance(value, list):
            self._labels = list()
            for i in value:
                if isinstance(i, LifeLabel):
                    self._labels.append(i)
                else:
                    self._labels.append(LifeLabel.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(AlipayOpenPublicLifeLabelBatchqueryResponse, self).parse_response_content(response_content)
        if 'labels' in response:
            self.labels = response['labels']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayMobileCodeCreateResponse(AlipayResponse):

    def __init__(self):
        super(AlipayMobileCodeCreateResponse, self).__init__()
        self._biz_linked_id = None
        self._biz_type = None
        self._code_status = None
        self._context_str = None
        self._dynamic_img_url = None
        self._expire_date = None
        self._is_direct = None
        self._memo = None
        self._qr_code = None
        self._qr_token = None
        self._source_id = None
        self._start_date = None
        self._user_id = None

    @property
    def biz_linked_id(self):
        return self._biz_linked_id

    @biz_linked_id.setter
    def biz_linked_id(self, value):
        self._biz_linked_id = value
    @property
    def biz_type(self):
        return self._biz_type

    @biz_type.setter
    def biz_type(self, value):
        self._biz_type = value
    @property
    def code_status(self):
        return self._code_status

    @code_status.setter
    def code_status(self, value):
        self._code_status = value
    @property
    def context_str(self):
        return self._context_str

    @context_str.setter
    def context_str(self, value):
        self._context_str = value
    @property
    def dynamic_img_url(self):
        return self._dynamic_img_url

    @dynamic_img_url.setter
    def dynamic_img_url(self, value):
        self._dynamic_img_url = value
    @property
    def expire_date(self):
        return self._expire_date

    @expire_date.setter
    def expire_date(self, value):
        self._expire_date = value
    @property
    def is_direct(self):
        return self._is_direct

    @is_direct.setter
    def is_direct(self, value):
        self._is_direct = value
    @property
    def memo(self):
        return self._memo

    @memo.setter
    def memo(self, value):
        self._memo = value
    @property
    def qr_code(self):
        return self._qr_code

    @qr_code.setter
    def qr_code(self, value):
        self._qr_code = value
    @property
    def qr_token(self):
        return self._qr_token

    @qr_token.setter
    def qr_token(self, value):
        self._qr_token = value
    @property
    def source_id(self):
        return self._source_id

    @source_id.setter
    def source_id(self, value):
        self._source_id = value
    @property
    def start_date(self):
        return self._start_date

    @start_date.setter
    def start_date(self, value):
        self._start_date = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value

    def parse_response_content(self, response_content):
        response = super(AlipayMobileCodeCreateResponse, self).parse_response_content(response_content)
        if 'biz_linked_id' in response:
            self.biz_linked_id = response['biz_linked_id']
        if 'biz_type' in response:
            self.biz_type = response['biz_type']
        if 'code_status' in response:
            self.code_status = response['code_status']
        if 'context_str' in response:
            self.context_str = response['context_str']
        if 'dynamic_img_url' in response:
            self.dynamic_img_url = response['dynamic_img_url']
        if 'expire_date' in response:
            self.expire_date = response['expire_date']
        if 'is_direct' in response:
            self.is_direct = response['is_direct']
        if 'memo' in response:
            self.memo = response['memo']
        if 'qr_code' in response:
            self.qr_code = response['qr_code']
        if 'qr_token' in response:
            self.qr_token = response['qr_token']
        if 'source_id' in response:
            self.source_id = response['source_id']
        if 'start_date' in response:
            self.start_date = response['start_date']
        if 'user_id' in response:
            self.user_id = response['user_id']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.OldComplextMockModel import OldComplextMockModel


class OldListListComplexMockModel(object):

    def __init__(self):
        self._cm_list = None

    @property
    def cm_list(self):
        return self._cm_list

    @cm_list.setter
    def cm_list(self, value):
        if isinstance(value, list):
            self._cm_list = list()
            for i in value:
                if isinstance(i, OldComplextMockModel):
                    self._cm_list.append(i)
                else:
                    self._cm_list.append(OldComplextMockModel.from_alipay_dict(i))


    def to_alipay_dict(self):
        params = dict()
        if self.cm_list:
            if isinstance(self.cm_list, list):
                for i in range(0, len(self.cm_list)):
                    element = self.cm_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.cm_list[i] = element.to_alipay_dict()
            if hasattr(self.cm_list, 'to_alipay_dict'):
                params['cm_list'] = self.cm_list.to_alipay_dict()
            else:
                params['cm_list'] = self.cm_list
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = OldListListComplexMockModel()
        if 'cm_list' in d:
            o.cm_list = d['cm_list']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayFundJointaccountFundplanDeleteModel(object):

    def __init__(self):
        self._account_id = None
        self._agreement_no = None
        self._biz_scene = None
        self._fund_plan_id = None
        self._identity = None
        self._identity_type = None
        self._product_code = None

    @property
    def account_id(self):
        return self._account_id

    @account_id.setter
    def account_id(self, value):
        self._account_id = value
    @property
    def agreement_no(self):
        return self._agreement_no

    @agreement_no.setter
    def agreement_no(self, value):
        self._agreement_no = value
    @property
    def biz_scene(self):
        return self._biz_scene

    @biz_scene.setter
    def biz_scene(self, value):
        self._biz_scene = value
    @property
    def fund_plan_id(self):
        return self._fund_plan_id

    @fund_plan_id.setter
    def fund_plan_id(self, value):
        self._fund_plan_id = value
    @property
    def identity(self):
        return self._identity

    @identity.setter
    def identity(self, value):
        self._identity = value
    @property
    def identity_type(self):
        return self._identity_type

    @identity_type.setter
    def identity_type(self, value):
        self._identity_type = value
    @property
    def product_code(self):
        return self._product_code

    @product_code.setter
    def product_code(self, value):
        self._product_code = value


    def to_alipay_dict(self):
        params = dict()
        if self.account_id:
            if hasattr(self.account_id, 'to_alipay_dict'):
                params['account_id'] = self.account_id.to_alipay_dict()
            else:
                params['account_id'] = self.account_id
        if self.agreement_no:
            if hasattr(self.agreement_no, 'to_alipay_dict'):
                params['agreement_no'] = self.agreement_no.to_alipay_dict()
            else:
                params['agreement_no'] = self.agreement_no
        if self.biz_scene:
            if hasattr(self.biz_scene, 'to_alipay_dict'):
                params['biz_scene'] = self.biz_scene.to_alipay_dict()
            else:
                params['biz_scene'] = self.biz_scene
        if self.fund_plan_id:
            if hasattr(self.fund_plan_id, 'to_alipay_dict'):
                params['fund_plan_id'] = self.fund_plan_id.to_alipay_dict()
            else:
                params['fund_plan_id'] = self.fund_plan_id
        if self.identity:
            if hasattr(self.identity, 'to_alipay_dict'):
                params['identity'] = self.identity.to_alipay_dict()
            else:
                params['identity'] = self.identity
        if self.identity_type:
            if hasattr(self.identity_type, 'to_alipay_dict'):
                params['identity_type'] = self.identity_type.to_alipay_dict()
            else:
                params['identity_type'] = self.identity_type
        if self.product_code:
            if hasattr(self.product_code, 'to_alipay_dict'):
                params['product_code'] = self.product_code.to_alipay_dict()
            else:
                params['product_code'] = self.product_code
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayFundJointaccountFundplanDeleteModel()
        if 'account_id' in d:
            o.account_id = d['account_id']
        if 'agreement_no' in d:
            o.agreement_no = d['agreement_no']
        if 'biz_scene' in d:
            o.biz_scene = d['biz_scene']
        if 'fund_plan_id' in d:
            o.fund_plan_id = d['fund_plan_id']
        if 'identity' in d:
            o.identity = d['identity']
        if 'identity_type' in d:
            o.identity_type = d['identity_type']
        if 'product_code' in d:
            o.product_code = d['product_code']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.AlipayOrderDataOpenapiResultInfo import AlipayOrderDataOpenapiResultInfo


class AlipayMerchantOrderConsumerQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayMerchantOrderConsumerQueryResponse, self).__init__()
        self._order_info = None

    @property
    def order_info(self):
        return self._order_info

    @order_info.setter
    def order_info(self, value):
        if isinstance(value, AlipayOrderDataOpenapiResultInfo):
            self._order_info = value
        else:
            self._order_info = AlipayOrderDataOpenapiResultInfo.from_alipay_dict(value)

    def parse_response_content(self, response_content):
        response = super(AlipayMerchantOrderConsumerQueryResponse, self).parse_response_content(response_content)
        if 'order_info' in response:
            self.order_info = response['order_info']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class RetailKbcodeQueryVo(object):

    def __init__(self):
        self._batch_id = None
        self._code_template = None
        self._code_tip = None
        self._code_url = None
        self._create_time = None
        self._qr_code = None
        self._resource_url = None
        self._salesman = None

    @property
    def batch_id(self):
        return self._batch_id

    @batch_id.setter
    def batch_id(self, value):
        self._batch_id = value
    @property
    def code_template(self):
        return self._code_template

    @code_template.setter
    def code_template(self, value):
        self._code_template = value
    @property
    def code_tip(self):
        return self._code_tip

    @code_tip.setter
    def code_tip(self, value):
        self._code_tip = value
    @property
    def code_url(self):
        return self._code_url

    @code_url.setter
    def code_url(self, value):
        self._code_url = value
    @property
    def create_time(self):
        return self._create_time

    @create_time.setter
    def create_time(self, value):
        self._create_time = value
    @property
    def qr_code(self):
        return self._qr_code

    @qr_code.setter
    def qr_code(self, value):
        self._qr_code = value
    @property
    def resource_url(self):
        return self._resource_url

    @resource_url.setter
    def resource_url(self, value):
        self._resource_url = value
    @property
    def salesman(self):
        return self._salesman

    @salesman.setter
    def salesman(self, value):
        self._salesman = value


    def to_alipay_dict(self):
        params = dict()
        if self.batch_id:
            if hasattr(self.batch_id, 'to_alipay_dict'):
                params['batch_id'] = self.batch_id.to_alipay_dict()
            else:
                params['batch_id'] = self.batch_id
        if self.code_template:
            if hasattr(self.code_template, 'to_alipay_dict'):
                params['code_template'] = self.code_template.to_alipay_dict()
            else:
                params['code_template'] = self.code_template
        if self.code_tip:
            if hasattr(self.code_tip, 'to_alipay_dict'):
                params['code_tip'] = self.code_tip.to_alipay_dict()
            else:
                params['code_tip'] = self.code_tip
        if self.code_url:
            if hasattr(self.code_url, 'to_alipay_dict'):
                params['code_url'] = self.code_url.to_alipay_dict()
            else:
                params['code_url'] = self.code_url
        if self.create_time:
            if hasattr(self.create_time, 'to_alipay_dict'):
                params['create_time'] = self.create_time.to_alipay_dict()
            else:
                params['create_time'] = self.create_time
        if self.qr_code:
            if hasattr(self.qr_code, 'to_alipay_dict'):
                params['qr_code'] = self.qr_code.to_alipay_dict()
            else:
                params['qr_code'] = self.qr_code
        if self.resource_url:
            if hasattr(self.resource_url, 'to_alipay_dict'):
                params['resource_url'] = self.resource_url.to_alipay_dict()
            else:
                params['resource_url'] = self.resource_url
        if self.salesman:
            if hasattr(self.salesman, 'to_alipay_dict'):
                params['salesman'] = self.salesman.to_alipay_dict()
            else:
                params['salesman'] = self.salesman
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = RetailKbcodeQueryVo()
        if 'batch_id' in d:
            o.batch_id = d['batch_id']
        if 'code_template' in d:
            o.code_template = d['code_template']
        if 'code_tip' in d:
            o.code_tip = d['code_tip']
        if 'code_url' in d:
            o.code_url = d['code_url']
        if 'create_time' in d:
            o.create_time = d['create_time']
        if 'qr_code' in d:
            o.qr_code = d['qr_code']
        if 'resource_url' in d:
            o.resource_url = d['resource_url']
        if 'salesman' in d:
            o.salesman = d['salesman']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class BenefitGradeConfig(object):

    def __init__(self):
        self._background_url = None
        self._detail = None
        self._grade = None
        self._page_url = None
        self._point = None
        self._point_discount = None

    @property
    def background_url(self):
        return self._background_url

    @background_url.setter
    def background_url(self, value):
        self._background_url = value
    @property
    def detail(self):
        return self._detail

    @detail.setter
    def detail(self, value):
        self._detail = value
    @property
    def grade(self):
        return self._grade

    @grade.setter
    def grade(self, value):
        self._grade = value
    @property
    def page_url(self):
        return self._page_url

    @page_url.setter
    def page_url(self, value):
        self._page_url = value
    @property
    def point(self):
        return self._point

    @point.setter
    def point(self, value):
        self._point = value
    @property
    def point_discount(self):
        return self._point_discount

    @point_discount.setter
    def point_discount(self, value):
        self._point_discount = value


    def to_alipay_dict(self):
        params = dict()
        if self.background_url:
            if hasattr(self.background_url, 'to_alipay_dict'):
                params['background_url'] = self.background_url.to_alipay_dict()
            else:
                params['background_url'] = self.background_url
        if self.detail:
            if hasattr(self.detail, 'to_alipay_dict'):
                params['detail'] = self.detail.to_alipay_dict()
            else:
                params['detail'] = self.detail
        if self.grade:
            if hasattr(self.grade, 'to_alipay_dict'):
                params['grade'] = self.grade.to_alipay_dict()
            else:
                params['grade'] = self.grade
        if self.page_url:
            if hasattr(self.page_url, 'to_alipay_dict'):
                params['page_url'] = self.page_url.to_alipay_dict()
            else:
                params['page_url'] = self.page_url
        if self.point:
            if hasattr(self.point, 'to_alipay_dict'):
                params['point'] = self.point.to_alipay_dict()
            else:
                params['point'] = self.point
        if self.point_discount:
            if hasattr(self.point_discount, 'to_alipay_dict'):
                params['point_discount'] = self.point_discount.to_alipay_dict()
            else:
                params['point_discount'] = self.point_discount
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = BenefitGradeConfig()
        if 'background_url' in d:
            o.background_url = d['background_url']
        if 'detail' in d:
            o.detail = d['detail']
        if 'grade' in d:
            o.grade = d['grade']
        if 'page_url' in d:
            o.page_url = d['page_url']
        if 'point' in d:
            o.point = d['point']
        if 'point_discount' in d:
            o.point_discount = d['point_discount']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOpenBpaasPushSyncModel(object):

    def __init__(self):
        self._bpaas_app_id = None
        self._bpaas_app_version = None
        self._device_sn = None
        self._supplier_id = None

    @property
    def bpaas_app_id(self):
        return self._bpaas_app_id

    @bpaas_app_id.setter
    def bpaas_app_id(self, value):
        self._bpaas_app_id = value
    @property
    def bpaas_app_version(self):
        return self._bpaas_app_version

    @bpaas_app_version.setter
    def bpaas_app_version(self, value):
        self._bpaas_app_version = value
    @property
    def device_sn(self):
        return self._device_sn

    @device_sn.setter
    def device_sn(self, value):
        if isinstance(value, list):
            self._device_sn = list()
            for i in value:
                self._device_sn.append(i)
    @property
    def supplier_id(self):
        return self._supplier_id

    @supplier_id.setter
    def supplier_id(self, value):
        self._supplier_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.bpaas_app_id:
            if hasattr(self.bpaas_app_id, 'to_alipay_dict'):
                params['bpaas_app_id'] = self.bpaas_app_id.to_alipay_dict()
            else:
                params['bpaas_app_id'] = self.bpaas_app_id
        if self.bpaas_app_version:
            if hasattr(self.bpaas_app_version, 'to_alipay_dict'):
                params['bpaas_app_version'] = self.bpaas_app_version.to_alipay_dict()
            else:
                params['bpaas_app_version'] = self.bpaas_app_version
        if self.device_sn:
            if isinstance(self.device_sn, list):
                for i in range(0, len(self.device_sn)):
                    element = self.device_sn[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.device_sn[i] = element.to_alipay_dict()
            if hasattr(self.device_sn, 'to_alipay_dict'):
                params['device_sn'] = self.device_sn.to_alipay_dict()
            else:
                params['device_sn'] = self.device_sn
        if self.supplier_id:
            if hasattr(self.supplier_id, 'to_alipay_dict'):
                params['supplier_id'] = self.supplier_id.to_alipay_dict()
            else:
                params['supplier_id'] = self.supplier_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenBpaasPushSyncModel()
        if 'bpaas_app_id' in d:
            o.bpaas_app_id = d['bpaas_app_id']
        if 'bpaas_app_version' in d:
            o.bpaas_app_version = d['bpaas_app_version']
        if 'device_sn' in d:
            o.device_sn = d['device_sn']
        if 'supplier_id' in d:
            o.supplier_id = d['supplier_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.DataSecCheckContent import DataSecCheckContent


class KoubeiMarketingDataMallCheckGetModel(object):

    def __init__(self):
        self._check_contents = None
        self._data_source = None

    @property
    def check_contents(self):
        return self._check_contents

    @check_contents.setter
    def check_contents(self, value):
        if isinstance(value, list):
            self._check_contents = list()
            for i in value:
                if isinstance(i, DataSecCheckContent):
                    self._check_contents.append(i)
                else:
                    self._check_contents.append(DataSecCheckContent.from_alipay_dict(i))
    @property
    def data_source(self):
        return self._data_source

    @data_source.setter
    def data_source(self, value):
        self._data_source = value


    def to_alipay_dict(self):
        params = dict()
        if self.check_contents:
            if isinstance(self.check_contents, list):
                for i in range(0, len(self.check_contents)):
                    element = self.check_contents[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.check_contents[i] = element.to_alipay_dict()
            if hasattr(self.check_contents, 'to_alipay_dict'):
                params['check_contents'] = self.check_contents.to_alipay_dict()
            else:
                params['check_contents'] = self.check_contents
        if self.data_source:
            if hasattr(self.data_source, 'to_alipay_dict'):
                params['data_source'] = self.data_source.to_alipay_dict()
            else:
                params['data_source'] = self.data_source
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KoubeiMarketingDataMallCheckGetModel()
        if 'check_contents' in d:
            o.check_contents = d['check_contents']
        if 'data_source' in d:
            o.data_source = d['data_source']
        return o


